@@ -1,3 +1,3 @@
 from webknossos.administration.project import Project
 from webknossos.administration.task import Task
-from webknossos.administration.user import User
+from webknossos.administration.user import Team, User
