@@ -1,2 +1,7 @@
 """ A client library for accessing webknossos """
 from .client import AuthenticatedClient, Client
+
+__all__ = (
+    "AuthenticatedClient",
+    "Client",
+)
