@@ -1,3 +1,4 @@
+from http import HTTPStatus
 from typing import Any, Dict
 
 import httpx
@@ -16,10 +17,11 @@ def _get_kwargs(
         client.base_url, typ=typ, id=id
     )
 
-    headers: Dict[str, Any] = client.get_headers()
+    headers: Dict[str, str] = client.get_headers()
     cookies: Dict[str, Any] = client.get_cookies()
 
     return {
+        "method": "patch",
         "url": url,
         "headers": headers,
         "cookies": cookies,
@@ -29,7 +31,7 @@ def _get_kwargs(
 
 def _build_response(*, response: httpx.Response) -> Response[Any]:
     return Response(
-        status_code=response.status_code,
+        status_code=HTTPStatus(response.status_code),
         content=response.content,
         headers=response.headers,
         parsed=None,
@@ -42,13 +44,23 @@ def sync_detailed(
     *,
     client: Client,
 ) -> Response[Any]:
+    """
+    Args:
+        typ (str):
+        id (str):
+
+    Returns:
+        Response[Any]
+    """
+
     kwargs = _get_kwargs(
         typ=typ,
         id=id,
         client=client,
     )
 
-    response = httpx.patch(
+    response = httpx.request(
+        verify=client.verify_ssl,
         **kwargs,
     )
 
@@ -61,13 +73,22 @@ async def asyncio_detailed(
     *,
     client: Client,
 ) -> Response[Any]:
+    """
+    Args:
+        typ (str):
+        id (str):
+
+    Returns:
+        Response[Any]
+    """
+
     kwargs = _get_kwargs(
         typ=typ,
         id=id,
         client=client,
     )
 
-    async with httpx.AsyncClient() as _client:
-        response = await _client.patch(**kwargs)
+    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
+        response = await _client.request(**kwargs)
 
     return _build_response(response=response)
