@@ -1,4 +1,5 @@
-from typing import Any, Dict, Optional
+from http import HTTPStatus
+from typing import Any, Dict, Optional, Union, cast
 
 import httpx
 
@@ -15,15 +16,16 @@ def _get_kwargs(
 ) -> Dict[str, Any]:
     url = "{}/api/annotations/{id}/info".format(client.base_url, id=id)
 
-    headers: Dict[str, Any] = client.get_headers()
+    headers: Dict[str, str] = client.get_headers()
     cookies: Dict[str, Any] = client.get_cookies()
 
-    params: Dict[str, Any] = {
-        "timestamp": timestamp,
-    }
+    params: Dict[str, Any] = {}
+    params["timestamp"] = timestamp
+
     params = {k: v for k, v in params.items() if v is not UNSET and v is not None}
 
     return {
+        "method": "get",
         "url": url,
         "headers": headers,
         "cookies": cookies,
@@ -32,17 +34,24 @@ def _get_kwargs(
     }
 
 
-def _parse_response(*, response: httpx.Response) -> Optional[AnnotationInfoResponse200]:
-    if response.status_code == 200:
+def _parse_response(
+    *, response: httpx.Response
+) -> Optional[Union[AnnotationInfoResponse200, Any]]:
+    if response.status_code == HTTPStatus.OK:
         response_200 = AnnotationInfoResponse200.from_dict(response.json())
 
         return response_200
+    if response.status_code == HTTPStatus.BAD_REQUEST:
+        response_400 = cast(Any, None)
+        return response_400
     return None
 
 
-def _build_response(*, response: httpx.Response) -> Response[AnnotationInfoResponse200]:
+def _build_response(
+    *, response: httpx.Response
+) -> Response[Union[AnnotationInfoResponse200, Any]]:
     return Response(
-        status_code=response.status_code,
+        status_code=HTTPStatus(response.status_code),
         content=response.content,
         headers=response.headers,
         parsed=_parse_response(response=response),
@@ -54,14 +63,25 @@ def sync_detailed(
     *,
     client: Client,
     timestamp: int,
-) -> Response[AnnotationInfoResponse200]:
+) -> Response[Union[AnnotationInfoResponse200, Any]]:
+    """Information about an annotation
+
+    Args:
+        id (str):
+        timestamp (int):
+
+    Returns:
+        Response[Union[AnnotationInfoResponse200, Any]]
+    """
+
     kwargs = _get_kwargs(
         id=id,
         client=client,
         timestamp=timestamp,
     )
 
-    response = httpx.get(
+    response = httpx.request(
+        verify=client.verify_ssl,
         **kwargs,
     )
 
@@ -73,8 +93,16 @@ def sync(
     *,
     client: Client,
     timestamp: int,
-) -> Optional[AnnotationInfoResponse200]:
-    """ """
+) -> Optional[Union[AnnotationInfoResponse200, Any]]:
+    """Information about an annotation
+
+    Args:
+        id (str):
+        timestamp (int):
+
+    Returns:
+        Response[Union[AnnotationInfoResponse200, Any]]
+    """
 
     return sync_detailed(
         id=id,
@@ -88,15 +116,25 @@ async def asyncio_detailed(
     *,
     client: Client,
     timestamp: int,
-) -> Response[AnnotationInfoResponse200]:
+) -> Response[Union[AnnotationInfoResponse200, Any]]:
+    """Information about an annotation
+
+    Args:
+        id (str):
+        timestamp (int):
+
+    Returns:
+        Response[Union[AnnotationInfoResponse200, Any]]
+    """
+
     kwargs = _get_kwargs(
         id=id,
         client=client,
         timestamp=timestamp,
     )
 
-    async with httpx.AsyncClient() as _client:
-        response = await _client.get(**kwargs)
+    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
+        response = await _client.request(**kwargs)
 
     return _build_response(response=response)
 
@@ -106,8 +144,16 @@ async def asyncio(
     *,
     client: Client,
     timestamp: int,
-) -> Optional[AnnotationInfoResponse200]:
-    """ """
+) -> Optional[Union[AnnotationInfoResponse200, Any]]:
+    """Information about an annotation
+
+    Args:
+        id (str):
+        timestamp (int):
+
+    Returns:
+        Response[Union[AnnotationInfoResponse200, Any]]
+    """
 
     return (
         await asyncio_detailed(
