@@ -1,3 +1,4 @@
+from http import HTTPStatus
 from typing import Any, Dict
 
 import httpx
@@ -13,10 +14,11 @@ def _get_kwargs(
 ) -> Dict[str, Any]:
     url = "{}/api/zarrPrivateLinks/{id}".format(client.base_url, id=id)
 
-    headers: Dict[str, Any] = client.get_headers()
+    headers: Dict[str, str] = client.get_headers()
     cookies: Dict[str, Any] = client.get_cookies()
 
     return {
+        "method": "get",
         "url": url,
         "headers": headers,
         "cookies": cookies,
@@ -26,7 +28,7 @@ def _get_kwargs(
 
 def _build_response(*, response: httpx.Response) -> Response[Any]:
     return Response(
-        status_code=response.status_code,
+        status_code=HTTPStatus(response.status_code),
         content=response.content,
         headers=response.headers,
         parsed=None,
@@ -38,12 +40,22 @@ def sync_detailed(
     *,
     client: Client,
 ) -> Response[Any]:
+    """Get the private zarr link for a user for a given id if it exists
+
+    Args:
+        id (str):
+
+    Returns:
+        Response[Any]
+    """
+
     kwargs = _get_kwargs(
         id=id,
         client=client,
     )
 
-    response = httpx.get(
+    response = httpx.request(
+        verify=client.verify_ssl,
         **kwargs,
     )
 
@@ -55,12 +67,21 @@ async def asyncio_detailed(
     *,
     client: Client,
 ) -> Response[Any]:
+    """Get the private zarr link for a user for a given id if it exists
+
+    Args:
+        id (str):
+
+    Returns:
+        Response[Any]
+    """
+
     kwargs = _get_kwargs(
         id=id,
         client=client,
     )
 
-    async with httpx.AsyncClient() as _client:
-        response = await _client.get(**kwargs)
+    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
+        response = await _client.request(**kwargs)
 
     return _build_response(response=response)
