@@ -1,3 +1,4 @@
+from http import HTTPStatus
 from typing import Any, Dict
 
 import httpx
@@ -12,10 +13,11 @@ def _get_kwargs(
 ) -> Dict[str, Any]:
     url = "{}/api/zarrPrivateLinks".format(client.base_url)
 
-    headers: Dict[str, Any] = client.get_headers()
+    headers: Dict[str, str] = client.get_headers()
     cookies: Dict[str, Any] = client.get_cookies()
 
     return {
+        "method": "get",
         "url": url,
         "headers": headers,
         "cookies": cookies,
@@ -25,7 +27,7 @@ def _get_kwargs(
 
 def _build_response(*, response: httpx.Response) -> Response[Any]:
     return Response(
-        status_code=response.status_code,
+        status_code=HTTPStatus(response.status_code),
         content=response.content,
         headers=response.headers,
         parsed=None,
@@ -36,11 +38,18 @@ def sync_detailed(
     *,
     client: Client,
 ) -> Response[Any]:
+    """List all existing private zarr links for a user
+
+    Returns:
+        Response[Any]
+    """
+
     kwargs = _get_kwargs(
         client=client,
     )
 
-    response = httpx.get(
+    response = httpx.request(
+        verify=client.verify_ssl,
         **kwargs,
     )
 
@@ -51,11 +60,17 @@ async def asyncio_detailed(
     *,
     client: Client,
 ) -> Response[Any]:
+    """List all existing private zarr links for a user
+
+    Returns:
+        Response[Any]
+    """
+
     kwargs = _get_kwargs(
         client=client,
     )
 
-    async with httpx.AsyncClient() as _client:
-        response = await _client.get(**kwargs)
+    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
+        response = await _client.request(**kwargs)
 
     return _build_response(response=response)
