@@ -1,3 +1,4 @@
+from http import HTTPStatus
 from typing import Any, Dict
 
 import httpx
@@ -15,10 +16,11 @@ def _get_kwargs(
         client.base_url, annotationId=annotation_id
     )
 
-    headers: Dict[str, Any] = client.get_headers()
+    headers: Dict[str, str] = client.get_headers()
     cookies: Dict[str, Any] = client.get_cookies()
 
     return {
+        "method": "get",
         "url": url,
         "headers": headers,
         "cookies": cookies,
@@ -28,7 +30,7 @@ def _get_kwargs(
 
 def _build_response(*, response: httpx.Response) -> Response[Any]:
     return Response(
-        status_code=response.status_code,
+        status_code=HTTPStatus(response.status_code),
         content=response.content,
         headers=response.headers,
         parsed=None,
@@ -40,12 +42,22 @@ def sync_detailed(
     *,
     client: Client,
 ) -> Response[Any]:
+    """List all existing private zarr links for a user for a given annotation
+
+    Args:
+        annotation_id (str):
+
+    Returns:
+        Response[Any]
+    """
+
     kwargs = _get_kwargs(
         annotation_id=annotation_id,
         client=client,
     )
 
-    response = httpx.get(
+    response = httpx.request(
+        verify=client.verify_ssl,
         **kwargs,
     )
 
@@ -57,12 +69,21 @@ async def asyncio_detailed(
     *,
     client: Client,
 ) -> Response[Any]:
+    """List all existing private zarr links for a user for a given annotation
+
+    Args:
+        annotation_id (str):
+
+    Returns:
+        Response[Any]
+    """
+
     kwargs = _get_kwargs(
         annotation_id=annotation_id,
         client=client,
     )
 
-    async with httpx.AsyncClient() as _client:
-        response = await _client.get(**kwargs)
+    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
+        response = await _client.request(**kwargs)
 
     return _build_response(response=response)
