@@ -1,3 +1,4 @@
+from http import HTTPStatus
 from typing import Any, Dict, List, Optional, Union
 
 import httpx
@@ -16,17 +17,20 @@ def _get_kwargs(
 ) -> Dict[str, Any]:
     url = "{}/api/users".format(client.base_url)
 
-    headers: Dict[str, Any] = client.get_headers()
+    headers: Dict[str, str] = client.get_headers()
     cookies: Dict[str, Any] = client.get_cookies()
 
-    params: Dict[str, Any] = {
-        "isEditable": is_editable,
-        "isTeamManagerOrAdmin": is_team_manager_or_admin,
-        "isAdmin": is_admin,
-    }
+    params: Dict[str, Any] = {}
+    params["isEditable"] = is_editable
+
+    params["isTeamManagerOrAdmin"] = is_team_manager_or_admin
+
+    params["isAdmin"] = is_admin
+
     params = {k: v for k, v in params.items() if v is not UNSET and v is not None}
 
     return {
+        "method": "get",
         "url": url,
         "headers": headers,
         "cookies": cookies,
@@ -37,8 +41,8 @@ def _get_kwargs(
 
 def _parse_response(
     *, response: httpx.Response
-) -> Optional[List[UserListResponse200Item]]:
-    if response.status_code == 200:
+) -> Optional[List["UserListResponse200Item"]]:
+    if response.status_code == HTTPStatus.OK:
         response_200 = []
         _response_200 = response.json()
         for response_200_item_data in _response_200:
@@ -54,9 +58,9 @@ def _parse_response(
 
 def _build_response(
     *, response: httpx.Response
-) -> Response[List[UserListResponse200Item]]:
+) -> Response[List["UserListResponse200Item"]]:
     return Response(
-        status_code=response.status_code,
+        status_code=HTTPStatus(response.status_code),
         content=response.content,
         headers=response.headers,
         parsed=_parse_response(response=response),
@@ -69,7 +73,19 @@ def sync_detailed(
     is_editable: Union[Unset, None, bool] = UNSET,
     is_team_manager_or_admin: Union[Unset, None, bool] = UNSET,
     is_admin: Union[Unset, None, bool] = UNSET,
-) -> Response[List[UserListResponse200Item]]:
+) -> Response[List["UserListResponse200Item"]]:
+    """List all users the requesting user is allowed to see (themself and users of whom they are admin or
+    team-manager).
+
+    Args:
+        is_editable (Union[Unset, None, bool]):
+        is_team_manager_or_admin (Union[Unset, None, bool]):
+        is_admin (Union[Unset, None, bool]):
+
+    Returns:
+        Response[List['UserListResponse200Item']]
+    """
+
     kwargs = _get_kwargs(
         client=client,
         is_editable=is_editable,
@@ -77,7 +93,8 @@ def sync_detailed(
         is_admin=is_admin,
     )
 
-    response = httpx.get(
+    response = httpx.request(
+        verify=client.verify_ssl,
         **kwargs,
     )
 
@@ -90,8 +107,18 @@ def sync(
     is_editable: Union[Unset, None, bool] = UNSET,
     is_team_manager_or_admin: Union[Unset, None, bool] = UNSET,
     is_admin: Union[Unset, None, bool] = UNSET,
-) -> Optional[List[UserListResponse200Item]]:
-    """ """
+) -> Optional[List["UserListResponse200Item"]]:
+    """List all users the requesting user is allowed to see (themself and users of whom they are admin or
+    team-manager).
+
+    Args:
+        is_editable (Union[Unset, None, bool]):
+        is_team_manager_or_admin (Union[Unset, None, bool]):
+        is_admin (Union[Unset, None, bool]):
+
+    Returns:
+        Response[List['UserListResponse200Item']]
+    """
 
     return sync_detailed(
         client=client,
@@ -107,7 +134,19 @@ async def asyncio_detailed(
     is_editable: Union[Unset, None, bool] = UNSET,
     is_team_manager_or_admin: Union[Unset, None, bool] = UNSET,
     is_admin: Union[Unset, None, bool] = UNSET,
-) -> Response[List[UserListResponse200Item]]:
+) -> Response[List["UserListResponse200Item"]]:
+    """List all users the requesting user is allowed to see (themself and users of whom they are admin or
+    team-manager).
+
+    Args:
+        is_editable (Union[Unset, None, bool]):
+        is_team_manager_or_admin (Union[Unset, None, bool]):
+        is_admin (Union[Unset, None, bool]):
+
+    Returns:
+        Response[List['UserListResponse200Item']]
+    """
+
     kwargs = _get_kwargs(
         client=client,
         is_editable=is_editable,
@@ -115,8 +154,8 @@ async def asyncio_detailed(
         is_admin=is_admin,
     )
 
-    async with httpx.AsyncClient() as _client:
-        response = await _client.get(**kwargs)
+    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
+        response = await _client.request(**kwargs)
 
     return _build_response(response=response)
 
@@ -127,8 +166,18 @@ async def asyncio(
     is_editable: Union[Unset, None, bool] = UNSET,
     is_team_manager_or_admin: Union[Unset, None, bool] = UNSET,
     is_admin: Union[Unset, None, bool] = UNSET,
-) -> Optional[List[UserListResponse200Item]]:
-    """ """
+) -> Optional[List["UserListResponse200Item"]]:
+    """List all users the requesting user is allowed to see (themself and users of whom they are admin or
+    team-manager).
+
+    Args:
+        is_editable (Union[Unset, None, bool]):
+        is_team_manager_or_admin (Union[Unset, None, bool]):
+        is_admin (Union[Unset, None, bool]):
+
+    Returns:
+        Response[List['UserListResponse200Item']]
+    """
 
     return (
         await asyncio_detailed(
