@@ -9,7 +9,12 @@ T = TypeVar("T", bound="AnnotationInfoResponse200AnnotationLayersItem")
 
 @attr.s(auto_attribs=True)
 class AnnotationInfoResponse200AnnotationLayersItem:
-    """ """
+    """
+    Attributes:
+        typ (str):
+        tracing_id (Union[Unset, str]):
+        name (Union[Unset, str]):
+    """
 
     typ: str
     tracing_id: Union[Unset, str] = UNSET
