@@ -1,18 +1,31 @@
-from typing import Any, Dict, List, Type, TypeVar, Union
+from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union
 
 import attr
 
-from ..models.annotation_info_response_200_user_teams_item import (
-    AnnotationInfoResponse200UserTeamsItem,
-)
 from ..types import UNSET, Unset
 
+if TYPE_CHECKING:
+    from ..models.annotation_info_response_200_user_teams_item import (
+        AnnotationInfoResponse200UserTeamsItem,
+    )
+
+
 T = TypeVar("T", bound="AnnotationInfoResponse200User")
 
 
 @attr.s(auto_attribs=True)
 class AnnotationInfoResponse200User:
-    """ """
+    """
+    Attributes:
+        id (str):
+        email (str):
+        first_name (str):
+        last_name (str):
+        is_admin (int):
+        is_dataset_manager (int):
+        is_anonymous (Union[Unset, int]):
+        teams (Union[Unset, List['AnnotationInfoResponse200UserTeamsItem']]):
+    """
 
     id: str
     email: str
@@ -21,7 +34,7 @@ class AnnotationInfoResponse200User:
     is_admin: int
     is_dataset_manager: int
     is_anonymous: Union[Unset, int] = UNSET
-    teams: Union[Unset, List[AnnotationInfoResponse200UserTeamsItem]] = UNSET
+    teams: Union[Unset, List["AnnotationInfoResponse200UserTeamsItem"]] = UNSET
     additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
@@ -61,6 +74,10 @@ class AnnotationInfoResponse200User:
 
     @classmethod
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+        from ..models.annotation_info_response_200_user_teams_item import (
+            AnnotationInfoResponse200UserTeamsItem,
+        )
+
         d = src_dict.copy()
         id = d.pop("id")
 
