@@ -9,7 +9,12 @@ T = TypeVar("T", bound="AnnotationInfoResponse200UserTeamsItem")
 
 @attr.s(auto_attribs=True)
 class AnnotationInfoResponse200UserTeamsItem:
-    """ """
+    """
+    Attributes:
+        id (str):
+        name (str):
+        is_team_manager (Union[Unset, int]):
+    """
 
     id: str
     name: str
