@@ -9,7 +9,11 @@ T = TypeVar("T", bound="AnnotationInfosByTaskIdResponse200ItemTaskNeededExperien
 
 @attr.s(auto_attribs=True)
 class AnnotationInfosByTaskIdResponse200ItemTaskNeededExperience:
-    """ """
+    """
+    Attributes:
+        domain (Union[Unset, str]):
+        value (Union[Unset, int]):
+    """
 
     domain: Union[Unset, str] = UNSET
     value: Union[Unset, int] = UNSET
