@@ -1,18 +1,31 @@
-from typing import Any, Dict, List, Type, TypeVar, Union
+from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union
 
 import attr
 
-from ..models.annotation_infos_by_task_id_response_200_item_task_type_settings import (
-    AnnotationInfosByTaskIdResponse200ItemTaskTypeSettings,
-)
 from ..types import UNSET, Unset
 
+if TYPE_CHECKING:
+    from ..models.annotation_infos_by_task_id_response_200_item_task_type_settings import (
+        AnnotationInfosByTaskIdResponse200ItemTaskTypeSettings,
+    )
+
+
 T = TypeVar("T", bound="AnnotationInfosByTaskIdResponse200ItemTaskType")
 
 
 @attr.s(auto_attribs=True)
 class AnnotationInfosByTaskIdResponse200ItemTaskType:
-    """ """
+    """
+    Attributes:
+        id (str):
+        description (str):
+        team_name (str):
+        summary (Union[Unset, str]):
+        team_id (Union[Unset, str]):
+        settings (Union[Unset, AnnotationInfosByTaskIdResponse200ItemTaskTypeSettings]):
+        recommended_configuration (Union[Unset, str]):
+        tracing_type (Union[Unset, str]):
+    """
 
     id: str
     description: str
@@ -20,7 +33,7 @@ class AnnotationInfosByTaskIdResponse200ItemTaskType:
     summary: Union[Unset, str] = UNSET
     team_id: Union[Unset, str] = UNSET
     settings: Union[
-        Unset, AnnotationInfosByTaskIdResponse200ItemTaskTypeSettings
+        Unset, "AnnotationInfosByTaskIdResponse200ItemTaskTypeSettings"
     ] = UNSET
     recommended_configuration: Union[Unset, str] = UNSET
     tracing_type: Union[Unset, str] = UNSET
@@ -63,6 +76,10 @@ class AnnotationInfosByTaskIdResponse200ItemTaskType:
 
     @classmethod
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+        from ..models.annotation_infos_by_task_id_response_200_item_task_type_settings import (
+            AnnotationInfosByTaskIdResponse200ItemTaskTypeSettings,
+        )
+
         d = src_dict.copy()
         id = d.pop("id")
 
