@@ -1,18 +1,31 @@
-from typing import Any, Dict, List, Type, TypeVar, Union
+from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union
 
 import attr
 
-from ..models.annotation_infos_by_task_id_response_200_item_user_teams_item import (
-    AnnotationInfosByTaskIdResponse200ItemUserTeamsItem,
-)
 from ..types import UNSET, Unset
 
+if TYPE_CHECKING:
+    from ..models.annotation_infos_by_task_id_response_200_item_user_teams_item import (
+        AnnotationInfosByTaskIdResponse200ItemUserTeamsItem,
+    )
+
+
 T = TypeVar("T", bound="AnnotationInfosByTaskIdResponse200ItemUser")
 
 
 @attr.s(auto_attribs=True)
 class AnnotationInfosByTaskIdResponse200ItemUser:
-    """ """
+    """
+    Attributes:
+        id (str):
+        email (str):
+        first_name (str):
+        last_name (str):
+        is_admin (int):
+        is_dataset_manager (int):
+        is_anonymous (Union[Unset, int]):
+        teams (Union[Unset, List['AnnotationInfosByTaskIdResponse200ItemUserTeamsItem']]):
+    """
 
     id: str
     email: str
@@ -22,7 +35,7 @@ class AnnotationInfosByTaskIdResponse200ItemUser:
     is_dataset_manager: int
     is_anonymous: Union[Unset, int] = UNSET
     teams: Union[
-        Unset, List[AnnotationInfosByTaskIdResponse200ItemUserTeamsItem]
+        Unset, List["AnnotationInfosByTaskIdResponse200ItemUserTeamsItem"]
     ] = UNSET
     additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
 
@@ -63,6 +76,10 @@ class AnnotationInfosByTaskIdResponse200ItemUser:
 
     @classmethod
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+        from ..models.annotation_infos_by_task_id_response_200_item_user_teams_item import (
+            AnnotationInfosByTaskIdResponse200ItemUserTeamsItem,
+        )
+
         d = src_dict.copy()
         id = d.pop("id")
 
