@@ -9,7 +9,12 @@ T = TypeVar("T", bound="AnnotationInfosByTaskIdResponse200ItemUserTeamsItem")
 
 @attr.s(auto_attribs=True)
 class AnnotationInfosByTaskIdResponse200ItemUserTeamsItem:
-    """ """
+    """
+    Attributes:
+        id (str):
+        name (str):
+        is_team_manager (Union[Unset, int]):
+    """
 
     id: str
     name: str
