@@ -1,30 +1,40 @@
-from typing import Any, Dict, List, Type, TypeVar, Union
+from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union
 
 import attr
 
-from ..models.build_info_response_200_webknossos import BuildInfoResponse200Webknossos
-from ..models.build_info_response_200_webknossos_wrap import (
-    BuildInfoResponse200WebknossosWrap,
-)
 from ..types import UNSET, Unset
 
+if TYPE_CHECKING:
+    from ..models.build_info_response_200_webknossos import (
+        BuildInfoResponse200Webknossos,
+    )
+    from ..models.build_info_response_200_webknossos_wrap import (
+        BuildInfoResponse200WebknossosWrap,
+    )
+
+
 T = TypeVar("T", bound="BuildInfoResponse200")
 
 
 @attr.s(auto_attribs=True)
 class BuildInfoResponse200:
-    """ """
+    """
+    Attributes:
+        webknossos (Union[Unset, BuildInfoResponse200Webknossos]):
+        webknossos_wrap (Union[Unset, BuildInfoResponse200WebknossosWrap]):
+        schema_version (Union[Unset, int]):
+        local_data_store_enabled (Union[Unset, int]):
+        local_tracing_store_enabled (Union[Unset, int]):
+    """
 
-    token: str
-    webknossos: Union[Unset, BuildInfoResponse200Webknossos] = UNSET
-    webknossos_wrap: Union[Unset, BuildInfoResponse200WebknossosWrap] = UNSET
+    webknossos: Union[Unset, "BuildInfoResponse200Webknossos"] = UNSET
+    webknossos_wrap: Union[Unset, "BuildInfoResponse200WebknossosWrap"] = UNSET
     schema_version: Union[Unset, int] = UNSET
     local_data_store_enabled: Union[Unset, int] = UNSET
     local_tracing_store_enabled: Union[Unset, int] = UNSET
     additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
-        token = self.token
         webknossos: Union[Unset, Dict[str, Any]] = UNSET
         if not isinstance(self.webknossos, Unset):
             webknossos = self.webknossos.to_dict()
@@ -39,11 +49,7 @@ class BuildInfoResponse200:
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
-        field_dict.update(
-            {
-                "token": token,
-            }
-        )
+        field_dict.update({})
         if webknossos is not UNSET:
             field_dict["webknossos"] = webknossos
         if webknossos_wrap is not UNSET:
@@ -59,9 +65,14 @@ class BuildInfoResponse200:
 
     @classmethod
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
-        d = src_dict.copy()
-        token = d.pop("token")
+        from ..models.build_info_response_200_webknossos import (
+            BuildInfoResponse200Webknossos,
+        )
+        from ..models.build_info_response_200_webknossos_wrap import (
+            BuildInfoResponse200WebknossosWrap,
+        )
 
+        d = src_dict.copy()
         _webknossos = d.pop("webknossos", UNSET)
         webknossos: Union[Unset, BuildInfoResponse200Webknossos]
         if isinstance(_webknossos, Unset):
@@ -85,7 +96,6 @@ class BuildInfoResponse200:
         local_tracing_store_enabled = d.pop("localTracingStoreEnabled", UNSET)
 
         build_info_response_200 = cls(
-            token=token,
             webknossos=webknossos,
             webknossos_wrap=webknossos_wrap,
             schema_version=schema_version,
