@@ -9,7 +9,18 @@ T = TypeVar("T", bound="BuildInfoResponse200Webknossos")
 
 @attr.s(auto_attribs=True)
 class BuildInfoResponse200Webknossos:
-    """ """
+    """
+    Attributes:
+        name (str):
+        ci_tag (Union[Unset, str]):
+        commit_hash (Union[Unset, str]):
+        ci_build (Union[Unset, str]):
+        scala_version (Union[Unset, str]):
+        version (Union[Unset, str]):
+        sbt_version (Union[Unset, str]):
+        datastore_api_version (Union[Unset, str]):
+        commit_date (Union[Unset, str]):
+    """
 
     name: str
     ci_tag: Union[Unset, str] = UNSET
