@@ -9,7 +9,16 @@ T = TypeVar("T", bound="BuildInfoResponse200WebknossosWrap")
 
 @attr.s(auto_attribs=True)
 class BuildInfoResponse200WebknossosWrap:
-    """ """
+    """
+    Attributes:
+        name (str):
+        built_at_millis (Union[Unset, str]):
+        commit_hash (Union[Unset, str]):
+        scala_version (Union[Unset, str]):
+        version (Union[Unset, str]):
+        sbt_version (Union[Unset, str]):
+        built_at_string (Union[Unset, str]):
+    """
 
     name: str
     built_at_millis: Union[Unset, str] = UNSET
