@@ -1,24 +1,48 @@
-from typing import Any, Dict, List, Type, TypeVar, Union
+from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union
 
 import attr
 
-from ..models.current_user_info_response_200_experiences import (
-    CurrentUserInfoResponse200Experiences,
-)
-from ..models.current_user_info_response_200_novel_user_experience_infos import (
-    CurrentUserInfoResponse200NovelUserExperienceInfos,
-)
-from ..models.current_user_info_response_200_teams_item import (
-    CurrentUserInfoResponse200TeamsItem,
-)
 from ..types import UNSET, Unset
 
+if TYPE_CHECKING:
+    from ..models.current_user_info_response_200_experiences import (
+        CurrentUserInfoResponse200Experiences,
+    )
+    from ..models.current_user_info_response_200_novel_user_experience_infos import (
+        CurrentUserInfoResponse200NovelUserExperienceInfos,
+    )
+    from ..models.current_user_info_response_200_teams_item import (
+        CurrentUserInfoResponse200TeamsItem,
+    )
+
+
 T = TypeVar("T", bound="CurrentUserInfoResponse200")
 
 
 @attr.s(auto_attribs=True)
 class CurrentUserInfoResponse200:
-    """ """
+    """
+    Attributes:
+        id (str):
+        email (str):
+        first_name (str):
+        last_name (str):
+        is_admin (int):
+        is_dataset_manager (int):
+        is_active (int):
+        experiences (CurrentUserInfoResponse200Experiences):
+        last_activity (int):
+        organization (str):
+        created (int):
+        is_organization_owner (Union[Unset, int]):
+        teams (Union[Unset, List['CurrentUserInfoResponse200TeamsItem']]):
+        is_anonymous (Union[Unset, int]):
+        is_editable (Union[Unset, int]):
+        novel_user_experience_infos (Union[Unset, CurrentUserInfoResponse200NovelUserExperienceInfos]):
+        selected_theme (Union[Unset, str]):
+        last_task_type_id (Union[Unset, str]):
+        is_super_user (Union[Unset, int]):
+    """
 
     id: str
     email: str
@@ -27,15 +51,16 @@ class CurrentUserInfoResponse200:
     is_admin: int
     is_dataset_manager: int
     is_active: int
-    experiences: CurrentUserInfoResponse200Experiences
+    experiences: "CurrentUserInfoResponse200Experiences"
     last_activity: int
     organization: str
     created: int
-    teams: Union[Unset, List[CurrentUserInfoResponse200TeamsItem]] = UNSET
+    is_organization_owner: Union[Unset, int] = UNSET
+    teams: Union[Unset, List["CurrentUserInfoResponse200TeamsItem"]] = UNSET
     is_anonymous: Union[Unset, int] = UNSET
     is_editable: Union[Unset, int] = UNSET
     novel_user_experience_infos: Union[
-        Unset, CurrentUserInfoResponse200NovelUserExperienceInfos
+        Unset, "CurrentUserInfoResponse200NovelUserExperienceInfos"
     ] = UNSET
     selected_theme: Union[Unset, str] = UNSET
     last_task_type_id: Union[Unset, str] = UNSET
@@ -55,6 +80,7 @@ class CurrentUserInfoResponse200:
         last_activity = self.last_activity
         organization = self.organization
         created = self.created
+        is_organization_owner = self.is_organization_owner
         teams: Union[Unset, List[Dict[str, Any]]] = UNSET
         if not isinstance(self.teams, Unset):
             teams = []
@@ -90,6 +116,8 @@ class CurrentUserInfoResponse200:
                 "created": created,
             }
         )
+        if is_organization_owner is not UNSET:
+            field_dict["isOrganizationOwner"] = is_organization_owner
         if teams is not UNSET:
             field_dict["teams"] = teams
         if is_anonymous is not UNSET:
@@ -109,6 +137,16 @@ class CurrentUserInfoResponse200:
 
     @classmethod
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+        from ..models.current_user_info_response_200_experiences import (
+            CurrentUserInfoResponse200Experiences,
+        )
+        from ..models.current_user_info_response_200_novel_user_experience_infos import (
+            CurrentUserInfoResponse200NovelUserExperienceInfos,
+        )
+        from ..models.current_user_info_response_200_teams_item import (
+            CurrentUserInfoResponse200TeamsItem,
+        )
+
         d = src_dict.copy()
         id = d.pop("id")
 
@@ -134,6 +172,8 @@ class CurrentUserInfoResponse200:
 
         created = d.pop("created")
 
+        is_organization_owner = d.pop("isOrganizationOwner", UNSET)
+
         teams = []
         _teams = d.pop("teams", UNSET)
         for teams_item_data in _teams or []:
@@ -176,6 +216,7 @@ class CurrentUserInfoResponse200:
             last_activity=last_activity,
             organization=organization,
             created=created,
+            is_organization_owner=is_organization_owner,
             teams=teams,
             is_anonymous=is_anonymous,
             is_editable=is_editable,
