@@ -1,36 +1,69 @@
-from typing import Any, Dict, List, Type, TypeVar, Union
+from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union, cast
 
 import attr
 
-from ..models.dataset_info_response_200_allowed_teams_item import (
-    DatasetInfoResponse200AllowedTeamsItem,
-)
-from ..models.dataset_info_response_200_data_source import (
-    DatasetInfoResponse200DataSource,
-)
-from ..models.dataset_info_response_200_data_store import (
-    DatasetInfoResponse200DataStore,
-)
 from ..types import UNSET, Unset
 
+if TYPE_CHECKING:
+    from ..models.dataset_info_response_200_allowed_teams_cumulative_item import (
+        DatasetInfoResponse200AllowedTeamsCumulativeItem,
+    )
+    from ..models.dataset_info_response_200_allowed_teams_item import (
+        DatasetInfoResponse200AllowedTeamsItem,
+    )
+    from ..models.dataset_info_response_200_data_source import (
+        DatasetInfoResponse200DataSource,
+    )
+    from ..models.dataset_info_response_200_data_store import (
+        DatasetInfoResponse200DataStore,
+    )
+
+
 T = TypeVar("T", bound="DatasetInfoResponse200")
 
 
 @attr.s(auto_attribs=True)
 class DatasetInfoResponse200:
-    """ """
+    """
+    Attributes:
+        name (str):
+        data_source (DatasetInfoResponse200DataSource):
+        data_store (DatasetInfoResponse200DataStore):
+        allowed_teams (List['DatasetInfoResponse200AllowedTeamsItem']):
+        is_active (int):
+        is_public (int):
+        description (str):
+        display_name (str):
+        created (int):
+        tags (List[Any]):
+        folder_id (str):
+        owning_organization (Union[Unset, str]):
+        allowed_teams_cumulative (Union[Unset, List['DatasetInfoResponse200AllowedTeamsCumulativeItem']]):
+        is_editable (Union[Unset, int]):
+        last_used_by_user (Union[Unset, int]):
+        logo_url (Union[Unset, str]):
+        sorting_key (Union[Unset, int]):
+        details (Union[Unset, str]):
+        is_unreported (Union[Unset, int]):
+        jobs_enabled (Union[Unset, int]):
+        publication (Union[Unset, str]):
+    """
 
     name: str
-    data_source: DatasetInfoResponse200DataSource
-    data_store: DatasetInfoResponse200DataStore
-    allowed_teams: List[DatasetInfoResponse200AllowedTeamsItem]
+    data_source: "DatasetInfoResponse200DataSource"
+    data_store: "DatasetInfoResponse200DataStore"
+    allowed_teams: List["DatasetInfoResponse200AllowedTeamsItem"]
     is_active: int
     is_public: int
     description: str
     display_name: str
     created: int
     tags: List[Any]
+    folder_id: str
     owning_organization: Union[Unset, str] = UNSET
+    allowed_teams_cumulative: Union[
+        Unset, List["DatasetInfoResponse200AllowedTeamsCumulativeItem"]
+    ] = UNSET
     is_editable: Union[Unset, int] = UNSET
     last_used_by_user: Union[Unset, int] = UNSET
     logo_url: Union[Unset, str] = UNSET
@@ -58,13 +91,20 @@ class DatasetInfoResponse200:
         description = self.description
         display_name = self.display_name
         created = self.created
-        tags = []
-        for tags_item_data in self.tags:
-            tags_item = tags_item_data
-
-            tags.append(tags_item)
+        tags = self.tags
 
+        folder_id = self.folder_id
         owning_organization = self.owning_organization
+        allowed_teams_cumulative: Union[Unset, List[Dict[str, Any]]] = UNSET
+        if not isinstance(self.allowed_teams_cumulative, Unset):
+            allowed_teams_cumulative = []
+            for allowed_teams_cumulative_item_data in self.allowed_teams_cumulative:
+                allowed_teams_cumulative_item = (
+                    allowed_teams_cumulative_item_data.to_dict()
+                )
+
+                allowed_teams_cumulative.append(allowed_teams_cumulative_item)
+
         is_editable = self.is_editable
         last_used_by_user = self.last_used_by_user
         logo_url = self.logo_url
@@ -88,10 +128,13 @@ class DatasetInfoResponse200:
                 "displayName": display_name,
                 "created": created,
                 "tags": tags,
+                "folderId": folder_id,
             }
         )
         if owning_organization is not UNSET:
             field_dict["owningOrganization"] = owning_organization
+        if allowed_teams_cumulative is not UNSET:
+            field_dict["allowedTeamsCumulative"] = allowed_teams_cumulative
         if is_editable is not UNSET:
             field_dict["isEditable"] = is_editable
         if last_used_by_user is not UNSET:
@@ -113,6 +156,19 @@ class DatasetInfoResponse200:
 
     @classmethod
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+        from ..models.dataset_info_response_200_allowed_teams_cumulative_item import (
+            DatasetInfoResponse200AllowedTeamsCumulativeItem,
+        )
+        from ..models.dataset_info_response_200_allowed_teams_item import (
+            DatasetInfoResponse200AllowedTeamsItem,
+        )
+        from ..models.dataset_info_response_200_data_source import (
+            DatasetInfoResponse200DataSource,
+        )
+        from ..models.dataset_info_response_200_data_store import (
+            DatasetInfoResponse200DataStore,
+        )
+
         d = src_dict.copy()
         name = d.pop("name")
 
@@ -139,15 +195,23 @@ class DatasetInfoResponse200:
 
         created = d.pop("created")
 
-        tags = []
-        _tags = d.pop("tags")
-        for tags_item_data in _tags:
-            tags_item = tags_item_data
+        tags = cast(List[Any], d.pop("tags"))
 
-            tags.append(tags_item)
+        folder_id = d.pop("folderId")
 
         owning_organization = d.pop("owningOrganization", UNSET)
 
+        allowed_teams_cumulative = []
+        _allowed_teams_cumulative = d.pop("allowedTeamsCumulative", UNSET)
+        for allowed_teams_cumulative_item_data in _allowed_teams_cumulative or []:
+            allowed_teams_cumulative_item = (
+                DatasetInfoResponse200AllowedTeamsCumulativeItem.from_dict(
+                    allowed_teams_cumulative_item_data
+                )
+            )
+
+            allowed_teams_cumulative.append(allowed_teams_cumulative_item)
+
         is_editable = d.pop("isEditable", UNSET)
 
         last_used_by_user = d.pop("lastUsedByUser", UNSET)
@@ -175,7 +239,9 @@ class DatasetInfoResponse200:
             display_name=display_name,
             created=created,
             tags=tags,
+            folder_id=folder_id,
             owning_organization=owning_organization,
+            allowed_teams_cumulative=allowed_teams_cumulative,
             is_editable=is_editable,
             last_used_by_user=last_used_by_user,
             logo_url=logo_url,
