@@ -9,7 +9,14 @@ T = TypeVar("T", bound="DatastoreListResponse200Item")
 
 @attr.s(auto_attribs=True)
 class DatastoreListResponse200Item:
-    """ """
+    """
+    Attributes:
+        name (str):
+        url (str):
+        allows_upload (int):
+        is_scratch (Union[Unset, int]):
+        is_connector (Union[Unset, int]):
+    """
 
     name: str
     url: str
