@@ -1,18 +1,33 @@
-from typing import Any, Dict, List, Type, TypeVar, Union
+from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union
 
 import attr
 
-from ..models.project_info_by_name_response_200_owner import (
-    ProjectInfoByNameResponse200Owner,
-)
 from ..types import UNSET, Unset
 
+if TYPE_CHECKING:
+    from ..models.project_info_by_name_response_200_owner import (
+        ProjectInfoByNameResponse200Owner,
+    )
+
+
 T = TypeVar("T", bound="ProjectInfoByNameResponse200")
 
 
 @attr.s(auto_attribs=True)
 class ProjectInfoByNameResponse200:
-    """ """
+    """
+    Attributes:
+        name (str):
+        team (str):
+        team_name (str):
+        priority (int):
+        paused (int):
+        expected_time (int):
+        id (str):
+        created (int):
+        owner (Union[Unset, ProjectInfoByNameResponse200Owner]):
+        is_blacklisted_from_report (Union[Unset, int]):
+    """
 
     name: str
     team: str
@@ -21,7 +36,8 @@ class ProjectInfoByNameResponse200:
     paused: int
     expected_time: int
     id: str
-    owner: Union[Unset, ProjectInfoByNameResponse200Owner] = UNSET
+    created: int
+    owner: Union[Unset, "ProjectInfoByNameResponse200Owner"] = UNSET
     is_blacklisted_from_report: Union[Unset, int] = UNSET
     additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
 
@@ -33,6 +49,7 @@ class ProjectInfoByNameResponse200:
         paused = self.paused
         expected_time = self.expected_time
         id = self.id
+        created = self.created
         owner: Union[Unset, Dict[str, Any]] = UNSET
         if not isinstance(self.owner, Unset):
             owner = self.owner.to_dict()
@@ -50,6 +67,7 @@ class ProjectInfoByNameResponse200:
                 "paused": paused,
                 "expectedTime": expected_time,
                 "id": id,
+                "created": created,
             }
         )
         if owner is not UNSET:
@@ -61,6 +79,10 @@ class ProjectInfoByNameResponse200:
 
     @classmethod
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+        from ..models.project_info_by_name_response_200_owner import (
+            ProjectInfoByNameResponse200Owner,
+        )
+
         d = src_dict.copy()
         name = d.pop("name")
 
@@ -76,6 +98,8 @@ class ProjectInfoByNameResponse200:
 
         id = d.pop("id")
 
+        created = d.pop("created")
+
         _owner = d.pop("owner", UNSET)
         owner: Union[Unset, ProjectInfoByNameResponse200Owner]
         if isinstance(_owner, Unset):
@@ -93,6 +117,7 @@ class ProjectInfoByNameResponse200:
             paused=paused,
             expected_time=expected_time,
             id=id,
+            created=created,
             owner=owner,
             is_blacklisted_from_report=is_blacklisted_from_report,
         )
