@@ -1,24 +1,48 @@
-from typing import Any, Dict, List, Type, TypeVar, Union
+from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union
 
 import attr
 
-from ..models.user_list_response_200_item_experiences import (
-    UserListResponse200ItemExperiences,
-)
-from ..models.user_list_response_200_item_novel_user_experience_infos import (
-    UserListResponse200ItemNovelUserExperienceInfos,
-)
-from ..models.user_list_response_200_item_teams_item import (
-    UserListResponse200ItemTeamsItem,
-)
 from ..types import UNSET, Unset
 
+if TYPE_CHECKING:
+    from ..models.user_list_response_200_item_experiences import (
+        UserListResponse200ItemExperiences,
+    )
+    from ..models.user_list_response_200_item_novel_user_experience_infos import (
+        UserListResponse200ItemNovelUserExperienceInfos,
+    )
+    from ..models.user_list_response_200_item_teams_item import (
+        UserListResponse200ItemTeamsItem,
+    )
+
+
 T = TypeVar("T", bound="UserListResponse200Item")
 
 
 @attr.s(auto_attribs=True)
 class UserListResponse200Item:
-    """ """
+    """
+    Attributes:
+        id (str):
+        email (str):
+        first_name (str):
+        last_name (str):
+        is_admin (int):
+        is_dataset_manager (int):
+        is_active (int):
+        experiences (UserListResponse200ItemExperiences):
+        last_activity (int):
+        organization (str):
+        created (int):
+        is_organization_owner (Union[Unset, int]):
+        teams (Union[Unset, List['UserListResponse200ItemTeamsItem']]):
+        is_anonymous (Union[Unset, int]):
+        is_editable (Union[Unset, int]):
+        novel_user_experience_infos (Union[Unset, UserListResponse200ItemNovelUserExperienceInfos]):
+        selected_theme (Union[Unset, str]):
+        last_task_type_id (Union[Unset, str]):
+        is_super_user (Union[Unset, int]):
+    """
 
     id: str
     email: str
@@ -27,15 +51,16 @@ class UserListResponse200Item:
     is_admin: int
     is_dataset_manager: int
     is_active: int
-    experiences: UserListResponse200ItemExperiences
+    experiences: "UserListResponse200ItemExperiences"
     last_activity: int
     organization: str
     created: int
-    teams: Union[Unset, List[UserListResponse200ItemTeamsItem]] = UNSET
+    is_organization_owner: Union[Unset, int] = UNSET
+    teams: Union[Unset, List["UserListResponse200ItemTeamsItem"]] = UNSET
     is_anonymous: Union[Unset, int] = UNSET
     is_editable: Union[Unset, int] = UNSET
     novel_user_experience_infos: Union[
-        Unset, UserListResponse200ItemNovelUserExperienceInfos
+        Unset, "UserListResponse200ItemNovelUserExperienceInfos"
     ] = UNSET
     selected_theme: Union[Unset, str] = UNSET
     last_task_type_id: Union[Unset, str] = UNSET
@@ -55,6 +80,7 @@ class UserListResponse200Item:
         last_activity = self.last_activity
         organization = self.organization
         created = self.created
+        is_organization_owner = self.is_organization_owner
         teams: Union[Unset, List[Dict[str, Any]]] = UNSET
         if not isinstance(self.teams, Unset):
             teams = []
@@ -90,6 +116,8 @@ class UserListResponse200Item:
                 "created": created,
             }
         )
+        if is_organization_owner is not UNSET:
+            field_dict["isOrganizationOwner"] = is_organization_owner
         if teams is not UNSET:
             field_dict["teams"] = teams
         if is_anonymous is not UNSET:
@@ -109,6 +137,16 @@ class UserListResponse200Item:
 
     @classmethod
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+        from ..models.user_list_response_200_item_experiences import (
+            UserListResponse200ItemExperiences,
+        )
+        from ..models.user_list_response_200_item_novel_user_experience_infos import (
+            UserListResponse200ItemNovelUserExperienceInfos,
+        )
+        from ..models.user_list_response_200_item_teams_item import (
+            UserListResponse200ItemTeamsItem,
+        )
+
         d = src_dict.copy()
         id = d.pop("id")
 
@@ -132,6 +170,8 @@ class UserListResponse200Item:
 
         created = d.pop("created")
 
+        is_organization_owner = d.pop("isOrganizationOwner", UNSET)
+
         teams = []
         _teams = d.pop("teams", UNSET)
         for teams_item_data in _teams or []:
@@ -174,6 +214,7 @@ class UserListResponse200Item:
             last_activity=last_activity,
             organization=organization,
             created=created,
+            is_organization_owner=is_organization_owner,
             teams=teams,
             is_anonymous=is_anonymous,
             is_editable=is_editable,
