@@ -4,7 +4,7 @@
 The high-level dataset API automatically reads and writes meta information for any dataset and updates them if necessary, such as the `datasource-properties.json`.
 
 A dataset (`webknossos.dataset.dataset.Dataset`) is the entry-point for this API.
-The dataset stores the data on disk in `.wkw`-files (see [webknossos-wrap (wkw)](https://github.com/scalableminds/webknossos-wrap)).
+The dataset stores the data on disk in `.wkw`-files (see [WEBKNOSSOS-wrap (wkw)](https://github.com/scalableminds/webknossos-wrap)).
 
 Each dataset consists of one or more layers (webknossos.dataset.layer.Layer), which themselves can comprise multiple magnifications (webknossos.dataset.mag_view.MagView).
 """
@@ -14,5 +14,6 @@ from .dataset import Dataset, RemoteDataset
 from .layer import Layer, SegmentationLayer
 from .layer_categories import COLOR_CATEGORY, SEGMENTATION_CATEGORY, LayerCategoryType
 from .mag_view import MagView
+from .remote_folder import RemoteFolder
 from .sampling_modes import SamplingModes
 from .view import View
