@@ -4,6 +4,8 @@ from itertools import chain
 from os import PathLike
 from pathlib import Path
 from typing import (
+    ContextManager,
+    Dict,
     Iterable,
     Iterator,
     List,
@@ -19,17 +21,44 @@ from typing import (
 from urllib.error import HTTPError
 
 import numpy as np
+from natsort import natsorted
+from numpy.typing import DTypeLike
+
+# pylint: disable=unused-import
+try:
+    from webknossos.dataset._utils.pims_czi_reader import PimsCziReader
+except ImportError:
+    PimsCziReader = type(None)  # type: ignore[misc,assignment]
+
+try:
+    import webknossos.dataset._utils.pims_dm_readers
+except ImportError:
+    pass
+
+try:
+    import webknossos.dataset._utils.pims_imagej_tiff_reader
+except ImportError:
+    pass
+# pylint: enable=unused-import
 
-from webknossos.dataset.layer import DTypeLike
 from webknossos.dataset.mag_view import MagView
 from webknossos.geometry.vec3_int import Vec3Int
 
 try:
     import pims
-except ImportError as e:
+except ImportError as import_error:
     raise RuntimeError(
         "Cannot import pims, please install it e.g. using 'webknossos[all]'"
-    ) from e
+    ) from import_error
+
+
+# Fix ImageIOReader not handling channels correctly. This might get fixed via
+# https://github.com/soft-matter/pims/pull/430
+pims.ImageIOReader.frame_shape = pims.FramesSequenceND.frame_shape
+
+
+def _assume_color_channel(dim_size: int, dtype: np.dtype) -> bool:
+    return dim_size == 1 or (dim_size == 3 and dtype == np.dtype("uint8"))
 
 
 class PimsImages:
@@ -42,11 +71,12 @@ class PimsImages:
         images: Union[str, Path, "pims.FramesSequence", List[Union[str, PathLike]]],
         channel: Optional[int],
         timepoint: Optional[int],
+        czi_channel: Optional[int],
         swap_xy: bool,
         flip_x: bool,
         flip_y: bool,
         flip_z: bool,
-        use_bioformats: bool,
+        use_bioformats: Optional[bool],
         is_segmentation: bool,
     ) -> None:
         """
@@ -74,6 +104,7 @@ class PimsImages:
         ## arguments as inner attributes
         self._channel = channel
         self._timepoint = timepoint
+        self._czi_channel = czi_channel
         self._swap_xy = swap_xy
         self._flip_x = flip_x
         self._flip_y = flip_y
@@ -82,6 +113,7 @@ class PimsImages:
 
         ## attributes that will be set in __init__()
         self._iter_dim = None
+        self._possible_layers = {}
         # _img_dims
 
         ## attributes only for pims.FramesSequenceND instances:
@@ -113,13 +145,20 @@ class PimsImages:
                 self._init_c_axis = False
                 if isinstance(images, pims.imageio_reader.ImageIOReader):
                     # bugfix for ImageIOReader which misses channel axis sometimes,
-                    # assuming channels come last:
+                    # assuming channels come last. This might get fixed via
+                    # https://github.com/soft-matter/pims/pull/430
                     if (
-                        len(images.shape) > len(images.sizes)
+                        len(images._shape) >= len(images.sizes)
                         and "c" not in images.sizes
                     ):
-                        images._init_axis("c", images.shape[-1])
+                        images._init_axis("c", images._shape[-1])
                         self._init_c_axis = True
+
+                if isinstance(images, PimsCziReader):
+                    available_czi_channels = images.available_czi_channels()
+                    if len(available_czi_channels) > 1:
+                        self._possible_layers["czi_channel"] = available_czi_channels
+
                 if images.sizes.get("c", 1) > 1:
                     self._img_dims = "cyx"
                 else:
@@ -136,34 +175,38 @@ class PimsImages:
 
                 if timepoint is None:
                     if images.sizes.get("t", 1) > 1:
-                        assert self._iter_dim != "z", (
-                            f"Found both axes t {images.sizes.get('t', 1) } "
-                            + f"and z {images.sizes.get('z', 1) > 1}, "
-                            + "cannot use both without setting timepoint"
-                        )
-                        self._iter_dim = "t"
+                        if self._iter_dim == "":
+                            self._iter_dim = "t"
+                        else:
+                            self._default_coords["t"] = 0
+                            self._possible_layers["timepoint"] = list(
+                                range(0, images.sizes["t"])
+                            )
                     elif "t" in images.axes:
                         self._default_coords["t"] = 0
                 else:
                     assert "t" in images.axes
                     self._default_coords["t"] = timepoint
             else:
+                # Fallback for generic pims classes that do not name their
+                # dimensions as pims.FramesSequenceND does:
+
                 _allow_channels_first = not is_segmentation
                 if isinstance(images, (pims.ImageSequence, pims.ReaderSequence)):
                     _allow_channels_first = False
+
                 if len(images.shape) == 2:
+                    # Assume yx
                     self._img_dims = "yx"
                     self._iter_dim = ""
                 elif len(images.shape) == 3:
-                    if images.shape[2] == 1 or (
-                        images.shape[2] == 3 and images.dtype == np.dtype("uint8")
-                    ):
+                    # Assume yxc, cyx or zyx
+                    if _assume_color_channel(images.shape[2], images.dtype):
                         self._img_dims = "yxc"
                         self._iter_dim = ""
                     elif images.shape[0] == 1 or (
                         _allow_channels_first
-                        and images.shape[0] == 3
-                        and images.dtype == np.dtype("uint8")
+                        and _assume_color_channel(images.shape[0], images.dtype)
                     ):
                         self._img_dims = "cyx"
                         self._iter_dim = ""
@@ -171,17 +214,40 @@ class PimsImages:
                         self._img_dims = "yx"
                         self._iter_dim = "z"
                 elif len(images.shape) == 4:
-                    if images.shape[1] == 1 or (
-                        images.shape[1] == 3 and images.dtype == np.dtype("uint8")
+                    # Assume zcyx or zyxc
+                    if images.shape[1] == 1 or _assume_color_channel(
+                        images.shape[1], images.dtype
                     ):
                         self._img_dims = "cyx"
                     else:
                         self._img_dims = "yxc"
                     self._iter_dim = "z"
+                elif len(images.shape) == 5:
+                    # Assume tzcyx or tzyxc
+                    # t has to be constant for this reader to obtain 4D image
+                    # (only possible if not specified manually already, since
+                    # the timepoint would already be indexed here and the
+                    # 5th dimension would be something else)
+                    if timepoint is not None:
+                        raise RuntimeError(
+                            f"Got {len(images.shape)} axes for the images after "
+                            + "removing time dimension, can only map to 3D+channels."
+                        )
+
+                    if _assume_color_channel(images.shape[2], images.dtype):
+                        self._img_dims = "cyx"
+                    else:
+                        self._img_dims = "yxc"
+                    self._iter_dim = "z"
+                    self._timepoint = 0
+                    if images.shape[0] > 1:
+                        self._possible_layers["timepoint"] = list(
+                            range(0, images.shape[0])
+                        )
                 else:
                     raise RuntimeError(
                         f"Got {len(images.shape)} axes for the images, "
-                        + "cannot map to 3D+channels, consider setting timepoint."
+                        + "cannot map to 3D+channels+timepoints."
                     )
 
         #############################
@@ -194,7 +260,7 @@ class PimsImages:
                     pims.FramesSequence, images[0]
                 ).shape
             else:
-                images_shape = images.shape
+                images_shape = images.shape  # pylint: disable=no-member
             c_index = self._img_dims.find("c")
             if c_index == -1:
                 self.num_channels = 1
@@ -218,12 +284,130 @@ class PimsImages:
                 self._channel < self.num_channels
             ), f"Selected channel {self._channel} (0-indexed), but only {self.num_channels} channels are available."
             self.num_channels = 1
-        elif self.num_channels > 3:
-            warnings.warn(
-                f"Found more than 3 channels ({self.num_channels}), clamping to the first 3."
+        else:
+            if self.num_channels == 2:
+                self._possible_layers["channel"] = [0, 1]
+                self.num_channels = 1
+                self._channel = 0
+            elif self.num_channels > 3:
+                self._possible_layers["channel"] = list(range(0, self.num_channels))
+                self.num_channels = 3
+                self._first_n_channels = 3
+
+    def _normalize_original_images(self) -> Union[str, List[str]]:
+        original_images = self._original_images
+        if isinstance(original_images, (str, Path)):
+            original_images_path = Path(original_images)
+            if original_images_path.is_dir():
+                valid_suffixes = get_valid_pims_suffixes()
+                original_images = natsorted(
+                    str(i)
+                    for i in original_images_path.glob("**/*")
+                    if i.is_file() and i.suffix.lstrip(".") in valid_suffixes
+                )
+                if len(original_images) == 1:
+                    original_images = original_images[0]
+        if isinstance(original_images, str):
+            return original_images
+        elif isinstance(original_images, Iterable):
+            return [str(i) for i in original_images]
+        else:
+            return str(original_images)
+
+    def _ensure_correct_bioformats_usage(
+        self, images_context_manager: pims.FramesSequence
+    ) -> None:
+        if (
+            isinstance(images_context_manager, pims.bioformats.BioformatsReader)
+            and self._use_bioformats == False
+        ):  # None is allowed
+            raise RuntimeError(
+                "Selected bioformats reader, but using bioformats is not allowed "
+                + "(use_bioformats is False)."
             )
-            self.num_channels = 3
-            self._first_n_channels = 3
+
+    def _try_open_pims_images(
+        self, original_images: Union[str, List[str]], exceptions: List[Exception]
+    ) -> Optional[pims.FramesSequence]:
+        if self._use_bioformats:
+            return None
+
+        open_kwargs = {}
+        if self._czi_channel is not None:
+            open_kwargs["czi_channel"] = self._czi_channel
+
+        # try normal pims.open
+        def strategy_0() -> pims.FramesSequence:
+            result = pims.open(original_images, **open_kwargs)
+            self._ensure_correct_bioformats_usage(original_images)
+            return result
+
+        # try pims.ImageSequence, which uses skimage internally but works for multiple images
+        strategy_1 = lambda: pims.ImageSequence(original_images)
+
+        # for image lists, try to guess the correct reader using only the first image,
+        # and apply that for all images via pims.ReaderSequence
+        def strategy_2() -> pims.FramesSequence:
+            if isinstance(original_images, list):
+                # assuming the same reader works for all images:
+                first_image_handler = pims.open(original_images[0], **open_kwargs)
+                self._ensure_correct_bioformats_usage(first_image_handler)
+                return pims.ReaderSequence(
+                    original_images, type(first_image_handler), **open_kwargs
+                )
+            else:
+                return None
+
+        for strategy in [strategy_0, strategy_1, strategy_2]:
+            try:
+                images_context_manager = strategy()
+            except Exception as e:
+                exceptions.append(e)
+            else:
+                if images_context_manager is not None:
+                    return images_context_manager
+        return None
+
+    def _try_open_bioformats_images_raw(
+        self,
+        original_images: Union[str, List[str]],
+        exceptions: List[Exception],
+    ) -> pims.FramesSequence:
+        try:
+            if self._use_bioformats == False:  # None is allowed
+                raise RuntimeError(
+                    "Using bioformats is not allowed (use_bioformats is False)."
+                )
+
+            # There is a wrong warning about jpype, supressing it here.
+            # See issue https://github.com/soft-matter/pims/issues/384
+            warnings.filterwarnings(
+                "ignore",
+                "Due to an issue with JPype 0.6.0, reading is slower.*",
+                category=UserWarning,
+                module="pims.bioformats",
+            )
+            try:
+                pims.bioformats._find_jar()
+            except HTTPError:
+                # We cannot use the newest bioformats version,
+                # since it does not include the necessary loci_tools.jar.
+                # Updates to support newer bioformats jars with pims are in PR
+                # https://github.com/soft-matter/pims/pull/403
+
+                # This is also part of the worker dockerfile to cache the
+                # jar in the image, please update Dockerfile.worker in the
+                # voxelytics repo accordingly when editing this.
+                pims.bioformats.download_jar(version="6.7.0")
+
+            if "*" in str(original_images) or isinstance(original_images, list):
+                return pims.ReaderSequence(
+                    original_images, pims.bioformats.BioformatsReader
+                )
+            else:
+                return pims.bioformats.BioformatsReader(original_images)
+        except Exception as e:
+            exceptions.append(e)
 
     @contextmanager
     def _open_images(
@@ -234,46 +418,35 @@ class PimsImages:
         after IDENTIFY AXIS ORDER of __init__() has run.
         For a 2D image this is achieved by wrapping it in a list.
         """
+        images_context_manager: Optional[ContextManager]
         with warnings.catch_warnings():
-
             if isinstance(self._original_images, pims.FramesSequence):
                 images_context_manager = nullcontext(enter_result=self._original_images)
             else:
-                if self._use_bioformats:
-                    # There is a wrong warning about jpype, supressing it here.
-                    # See issue https://github.com/soft-matter/pims/issues/384
-                    warnings.filterwarnings(
-                        "ignore",
-                        "Due to an issue with JPype 0.6.0, reading is slower.*",
-                        category=UserWarning,
-                        module="pims.bioformats",
+                exceptions: List[Exception] = []
+                original_images = self._normalize_original_images()
+                images_context_manager = None
+
+                images_context_manager = self._try_open_pims_images(
+                    original_images, exceptions
+                )
+
+                if images_context_manager is None:
+                    images_context_manager = self._try_open_bioformats_images_raw(
+                        original_images, exceptions
                     )
-                    try:
-                        pims.bioformats._find_jar()
-                    except HTTPError:
-                        # We cannot use the newest bioformats version,
-                        # since it does not include the necessary loci_tools.jar.
-                        # Updates to support newer bioformats jars with pims are in PR
-                        # https://github.com/soft-matter/pims/pull/403
-                        pims.bioformats.download_jar(version="6.7.0")
-                    if "*" in str(self._original_images) or isinstance(
-                        self._original_images, list
-                    ):
-                        images_context_manager = pims.ReaderSequence(
-                            self._original_images, pims.bioformats.BioformatsReader
-                        )
+
+                if images_context_manager is None:
+                    if len(exceptions) == 1:
+                        raise exceptions[0]
                     else:
-                        images_context_manager = pims.bioformats.BioformatsReader(
-                            self._original_images
+                        exceptions_str = "\n".join(
+                            f"{type(e).__name__}: {str(e)}" for e in exceptions
+                        )
+                        raise ValueError(
+                            f"Tried to open the images {self._original_images} with different methods, "
+                            + f"none succeded. The following errors were raised:\n{exceptions_str}"
                         )
-                else:
-                    original_images = self._original_images
-                    if isinstance(original_images, Path):
-                        original_images = str(original_images)
-                    try:
-                        images_context_manager = pims.open(original_images)
-                    except Exception:
-                        images_context_manager = pims.ImageSequence(original_images)
 
             with images_context_manager as images:
                 if isinstance(images, pims.FramesSequenceND):
@@ -283,7 +456,8 @@ class PimsImages:
                         if self._init_c_axis and "c" not in images.sizes:
                             # Bugfix for ImageIOReader which misses channel axis sometimes,
                             # assuming channels come last. _init_c_axis is set in __init__().
-                            images._init_axis("c", images.shape[-1])
+                            # This might get fixed via https://github.com/soft-matter/pims/pull/430
+                            images._init_axis("c", images._shape[-1])
                             for key in list(images._get_frame_dict.keys()):
                                 images._get_frame_dict[
                                     key + ("c",)
@@ -358,6 +532,12 @@ class PimsImages:
 
             return dimwise_max(shapes), None if max_id is None else int(max_id)
 
+    def get_possible_layers(self) -> Optional[Dict["str", List[int]]]:
+        if len(self._possible_layers) == 0:
+            return None
+        else:
+            return self._possible_layers
+
 
 T = TypeVar("T", bound=Tuple[int, ...])
 
@@ -398,7 +578,7 @@ def get_valid_pims_suffixes() -> Set[str]:
 
 def has_image_z_dimension(
     filepath: Path,
-    use_bioformats: bool,
+    use_bioformats: Optional[bool],
     is_segmentation: bool,
 ) -> bool:
 
@@ -409,6 +589,7 @@ def has_image_z_dimension(
         # the following arguments shouldn't matter much for the Dataset.from_images method:
         channel=None,
         timepoint=None,
+        czi_channel=None,
         swap_xy=False,
         flip_x=False,
         flip_y=False,
