@@ -7,6 +7,7 @@ import warnings
 from argparse import Namespace
 from contextlib import nullcontext
 from enum import Enum, unique
+from itertools import product
 from os import PathLike
 from os.path import relpath
 from pathlib import Path
@@ -31,11 +32,18 @@ import numpy as np
 from boltons.typeutils import make_sentinel
 from cluster_tools import Executor
 from natsort import natsort_keygen
+from numpy.typing import DTypeLike
 from upath import UPath
 
+from webknossos.dataset.defaults import (
+    DEFAULT_CHUNK_SHAPE,
+    DEFAULT_CHUNKS_PER_SHARD_ZARR,
+)
+
 from ..geometry.vec3_int import Vec3Int, Vec3IntLike
 from ._array import ArrayException, ArrayInfo, BaseArray, DataFormat
 from .remote_dataset_registry import RemoteDatasetRegistry
+from .remote_folder import RemoteFolder
 from .sampling_modes import SamplingModes
 
 if TYPE_CHECKING:
@@ -58,7 +66,6 @@ from ..utils import (
 from ._utils.from_images import guess_if_segmentation_path
 from ._utils.infer_bounding_box_existing_files import infer_bounding_box_existing_files
 from .layer import (
-    DTypeLike,
     Layer,
     SegmentationLayer,
     _dtype_per_channel_to_element_class,
@@ -162,7 +169,10 @@ class Dataset:
         parts of the stacks are in different folders."""
 
         def _to_callable(
-            self, input_path: Path, input_files: Sequence[Path], use_bioformats: bool
+            self,
+            input_path: Path,
+            input_files: Sequence[Path],
+            use_bioformats: Optional[bool],
         ) -> Callable[[Path], str]:
             from ._utils.pims_images import has_image_z_dimension
 
@@ -367,10 +377,13 @@ class Dataset:
         * organization_id,
         * sharing_token.
         """
+        from webknossos.client._resolve_short_link import resolve_short_link
         from webknossos.client.context import _get_context, webknossos_context
 
         caller = inspect.stack()[1].function
 
+        dataset_name_or_url = resolve_short_link(dataset_name_or_url)
+
         match = re.match(_DATASET_URL_REGEX, dataset_name_or_url)
         if match is not None:
             assert (
@@ -550,12 +563,13 @@ class Dataset:
         flip_x: bool = False,
         flip_y: bool = False,
         flip_z: bool = False,
-        use_bioformats: bool = False,
+        use_bioformats: Optional[bool] = None,
+        max_layers: int = 20,
         batch_size: Optional[int] = None,
         executor: Optional[Executor] = None,
     ) -> "Dataset":
         """
-        This method imports image data in a folder as a webKnossos dataset. The
+        This method imports image data in a folder as a WEBKNOSSOS dataset. The
         image data can be 3D images (such as multipage tiffs) or stacks of 2D
         images. In case of multiple 3D images or image stacks, those are mapped
         to different layers. The exact mapping is handled by the argument
@@ -633,6 +647,8 @@ class Dataset:
                 flip_z=flip_z,
                 use_bioformats=use_bioformats,
                 batch_size=batch_size,
+                allow_multiple_layers=True,
+                max_layers=max_layers - len(ds.layers),
                 executor=executor,
             )
 
@@ -696,11 +712,11 @@ class Dataset:
         jobs: Optional[int] = None,
     ) -> "RemoteDataset":
         """
-        Uploads this dataset to webKnossos.
+        Uploads this dataset to WEBKNOSSOS.
 
         The `new_dataset_name` parameter allows to assign a specific name for the dataset.
         `layers_to_link` allows to add (or override) a layer in the uploaded dataset, so that
-        it links to a layer of an existing dataset in webKnossos. That way, already existing
+        it links to a layer of an existing dataset in WEBKNOSSOS. That way, already existing
         layers don't need to be uploaded again.
 
         If supplied, the `jobs` parameter will determine the number of simultaneous chunk uploads. Defaults to 5.
@@ -984,10 +1000,14 @@ class Dataset:
         flip_y: bool = False,
         flip_z: bool = False,
         dtype: Optional[DTypeLike] = None,
-        use_bioformats: bool = False,
+        use_bioformats: Optional[bool] = None,
         channel: Optional[int] = None,
         timepoint: Optional[int] = None,
+        czi_channel: Optional[int] = None,
         batch_size: Optional[int] = None,  # defaults to shard-size z
+        allow_multiple_layers: bool = False,
+        max_layers: int = 20,
+        truncate_rgba_to_rgb: bool = True,
         executor: Optional[Executor] = None,
         chunk_size: Optional[Union[Vec3IntLike, int]] = None,  # deprecated
     ) -> Layer:
@@ -1012,10 +1032,16 @@ class Dataset:
         * `swap_xy`: set to `True` to interchange x and y axis before writing to disk
         * `flip_x`, `flip_y`, `flip_z`: set to `True` to reverse the respective axis before writing to disk
         * `dtype`: the read image data will be convertoed to this dtype using `numpy.ndarray.astype`
-        * `use_bioformats`: set to `True` to use the [pims bioformats adapter](https://soft-matter.github.io/pims/v0.6.1/bioformats.html), needs a JVM
-        * `channel`: may be used to select a single channel, if multiple are available,
+        * `use_bioformats`: set to `True` to only use the
+          [pims bioformats adapter](https://soft-matter.github.io/pims/v0.6.1/bioformats.html) directly, needs a JVM,
+          set to `False` to forbid using the bioformats adapter, by default it is tried as a last option
+        * `channel`: may be used to select a single channel, if multiple are available
         * `timepoint`: for timeseries, select a timepoint to use by specifying it as an int, starting from 0
+        * `czi_channel`: may be used to select a channel for .czi images, which differs from normal color-channels
         * `batch_size`: size to process the images, must be a multiple of the chunk-size z-axis for uncompressed and the shard-size z-axis for compressed layers, default is the chunk-size or shard-size respectively
+        * `allow_multiple_layers`: set to `True` if timepoints or channels may result in multiple layers being added (only the first is returned)
+        * `max_layers`: only applies if `allow_multiple_layers=True`, limits the number of layers added via different channels or timepoints
+        * `truncate_rgba_to_rgb`: only applies if `allow_multiple_layers=True`, set to `False` to write four channels into layers instead of an RGB channel
         * `executor`: pass a `ClusterExecutor` instance to parallelize the conversion jobs across the batches
         """
         from ._utils.pims_images import PimsImages, dimwise_max
@@ -1032,6 +1058,7 @@ class Dataset:
             images,
             channel=channel,
             timepoint=timepoint,
+            czi_channel=czi_channel,
             swap_xy=swap_xy,
             flip_x=flip_x,
             flip_y=flip_y,
@@ -1039,96 +1066,197 @@ class Dataset:
             use_bioformats=use_bioformats,
             is_segmentation=category == "segmentation",
         )
+        possible_layers = pims_images.get_possible_layers()
+        # Check if 4 color channels should be converted to
+        # 3 color channels (rbg)
+        if (
+            possible_layers is not None
+            and truncate_rgba_to_rgb
+            and len(possible_layers.get("channel", [])) == 4
+        ):
+            # Remove channels from possible_layers to keep those
+            # and automatically truncate to 3 channels
+            # (pims_images takes care of this:)
+            del possible_layers["channel"]
+        # Further below, we iterate over suffix_with_pims_open_kwargs_per_layer in the for-loop
+        # to add one layer per possible_layer if allow_multiple_layers is True.
+        # If just a single layer is added, we still add a default value in the dict.
+        if possible_layers is not None and len(possible_layers) > 0:
+            if allow_multiple_layers:
+                # Get all combinations of possible layers. E.g.
+                # possible_layers = {
+                #    "channel": [0, 1, 3, 4, 5],
+                #    "timepoint": [0, 1],
+                # }
+                # suffix_with_pims_open_kwargs_per_layer = {
+                #    "__channel0_timepoint0", {"channel": 0, "timepoint": 0},
+                #    "__channel0_timepoint1", {"channel": 0, "timepoint": 1},
+                #    "__channel0_timepoint2", {"channel": 0, "timepoint": 2},
+                #    …,
+                #    "__channel1_timepoint0", {"channel": 1, "timepoint": 0},
+                #    …,
+                # }
+                suffix_with_pims_open_kwargs_per_layer = {
+                    "__" + "_".join(f"{k}{v}" for k, v in sorted(pairs)): dict(pairs)
+                    for pairs in product(
+                        *(
+                            [(key, value) for value in values]
+                            for key, values in possible_layers.items()
+                        )
+                    )
+                }
+            else:
+                # initialize PimsImages as above, with normal layer name
+                suffix_with_pims_open_kwargs_per_layer = {"": {}}
+                warnings.warn(
+                    f"There are dimensions beyond channels and xyz which cannot be read: {possible_layers}. "
+                    "Defaulting to the first one. "
+                    "Please set allow_multiple_layers=True if all of them should be written to different layers, "
+                    "or set specific values as arguments.",
+                    RuntimeWarning,
+                )
+        else:
+            # initialize PimsImages as above, with normal layer name
+            suffix_with_pims_open_kwargs_per_layer = {"": {}}
+        first_layer = None
         add_layer_kwargs = {}
         if category == "segmentation":
             add_layer_kwargs["largest_segment_id"] = 0
-        layer = self.add_layer(
-            layer_name=layer_name,
-            category=category,
-            data_format=data_format,
-            dtype_per_channel=pims_images.dtype if dtype is None else dtype,
-            num_channels=pims_images.num_channels,
-            **add_layer_kwargs,  # type: ignore[arg-type]
-        )
-        mag_view = layer.add_mag(
-            mag=mag,
-            chunk_shape=chunk_shape,
-            chunks_per_shard=chunks_per_shard,
-            compress=compress,
-        )
-        mag = mag_view.mag
-        layer.bounding_box = (
-            BoundingBox((0, 0, 0), pims_images.expected_shape)
-            .from_mag_to_mag1(mag)
-            .offset(topleft)
-        )
-
-        if batch_size is None:
-            if compress:
-                batch_size = mag_view.info.shard_shape.z
-            else:
-                batch_size = mag_view.info.chunk_shape.z
-        elif compress:
-            assert (
-                batch_size % mag_view.info.shard_shape.z == 0
-            ), f"batch_size {batch_size} must be divisible by z shard-size {mag_view.info.shard_shape.z} when creating compressed layers"
-        else:
-            assert (
-                batch_size % mag_view.info.chunk_shape.z == 0
-            ), f"batch_size {batch_size} must be divisible by z chunk-size {mag_view.info.chunk_shape.z}"
-
-        func_per_chunk = named_partial(
-            pims_images.copy_to_view,
-            mag_view=mag_view,
-            is_segmentation=category == "segmentation",
-            dtype=dtype,
-        )
-
-        args = []
-        for z_start in range(0, pims_images.expected_shape.z, batch_size):
-            z_end = min(z_start + batch_size, pims_images.expected_shape.z)
-            # return shapes and set to union when using --pad
-            args.append((z_start, z_end))
-        with warnings.catch_warnings():
-            # Block alignmnent within the dataset should not be a problem, since shard-wise chunking is enforced.
-            # However, dataset borders might change between different parallelized writes, when sizes differ.
-            # For differing sizes, a separate warning is thrown, so block alignment warnings can be ignored:
-            warnings.filterwarnings(
-                "ignore",
-                message=_BLOCK_ALIGNMENT_WARNING,
-                category=RuntimeWarning,
-                module="webknossos",
+        if len(suffix_with_pims_open_kwargs_per_layer) > max_layers:
+            warnings.warn(
+                f"Limiting the number of added layers to {max_layers} out of {len(suffix_with_pims_open_kwargs_per_layer)}. "
+                + "Please increase max_layers if you want more layers to be added.",
+                RuntimeWarning,
             )
-            # There are race-conditions about setting the bbox of the layer.
-            # The bbox is set correctly afterwards, ignore errors here:
-            warnings.filterwarnings(
-                "ignore",
-                message=".*properties were found on disk which are newer than the ones that were seen last time.*",
-                category=UserWarning,
-                module="webknossos",
-            )
-            with get_executor_for_args(None, executor) as executor:
-                shapes_and_max_ids = wait_and_ensure_success(
-                    executor.map_to_futures(func_per_chunk, args),
-                    progress_desc="Creating layer from images",
+        for _, (
+            layer_name_suffix,
+            pims_open_kwargs,
+        ) in zip(range(max_layers), suffix_with_pims_open_kwargs_per_layer.items()):
+            # If pims_open_kwargs is empty there's no need to re-open the images:
+            if len(pims_open_kwargs) > 0:
+                # Set parameters from this method as default
+                # if they are not part of the kwargs per layer:
+                pims_open_kwargs.setdefault("timepoint", timepoint)
+                pims_open_kwargs.setdefault("channel", channel)
+                pims_open_kwargs.setdefault("czi_channel", czi_channel)
+                pims_images = PimsImages(
+                    images,
+                    swap_xy=swap_xy,
+                    flip_x=flip_x,
+                    flip_y=flip_y,
+                    flip_z=flip_z,
+                    use_bioformats=use_bioformats,
+                    is_segmentation=category == "segmentation",
+                    **pims_open_kwargs,
                 )
-            shapes, max_ids = zip(*shapes_and_max_ids)
-            if category == "segmentation":
-                max_id = max(max_ids)
-                cast(SegmentationLayer, layer).largest_segment_id = max_id
-            actual_size = Vec3Int(dimwise_max(shapes) + (pims_images.expected_shape.z,))
+            if dtype is None:
+                current_dtype = np.dtype(pims_images.dtype)
+                if current_dtype.byteorder == ">":
+                    current_dtype = current_dtype.newbyteorder("<")
+            else:
+                current_dtype = np.dtype(dtype)
+            layer = self.add_layer(
+                layer_name=layer_name + layer_name_suffix,
+                category=category,
+                data_format=data_format,
+                dtype_per_channel=current_dtype,
+                num_channels=pims_images.num_channels,
+                **add_layer_kwargs,  # type: ignore[arg-type]
+            )
+            if (
+                pims_images.expected_shape.z == 1
+                and layer.data_format == DataFormat.Zarr
+            ):
+                if chunk_shape is None:
+                    chunk_shape = DEFAULT_CHUNK_SHAPE.with_z(1)
+                if chunks_per_shard is None:
+                    # chunks_per_shard is 1 by default for zarr atm, but this
+                    # might change in the future:
+                    chunks_per_shard = DEFAULT_CHUNKS_PER_SHARD_ZARR.with_z(1)
+            mag_view = layer.add_mag(
+                mag=mag,
+                chunk_shape=chunk_shape,
+                chunks_per_shard=chunks_per_shard,
+                compress=compress,
+            )
+            mag = mag_view.mag
             layer.bounding_box = (
-                BoundingBox((0, 0, 0), actual_size)
+                BoundingBox((0, 0, 0), pims_images.expected_shape)
                 .from_mag_to_mag1(mag)
                 .offset(topleft)
             )
-        if pims_images.expected_shape != actual_size:
-            warnings.warn(
-                "Some images are larger than expected, smaller slices are padded with zeros now. "
-                + f"New size is {actual_size}, expected {pims_images.expected_shape}.",
-                RuntimeWarning,
+
+            if batch_size is None:
+                if compress:
+                    batch_size = mag_view.info.shard_shape.z
+                else:
+                    batch_size = mag_view.info.chunk_shape.z
+            elif compress:
+                assert (
+                    batch_size % mag_view.info.shard_shape.z == 0
+                ), f"batch_size {batch_size} must be divisible by z shard-size {mag_view.info.shard_shape.z} when creating compressed layers"
+            else:
+                assert (
+                    batch_size % mag_view.info.chunk_shape.z == 0
+                ), f"batch_size {batch_size} must be divisible by z chunk-size {mag_view.info.chunk_shape.z}"
+
+            func_per_chunk = named_partial(
+                pims_images.copy_to_view,
+                mag_view=mag_view,
+                is_segmentation=category == "segmentation",
+                dtype=current_dtype,
             )
-        return layer
+
+            args = []
+            for z_start in range(0, pims_images.expected_shape.z, batch_size):
+                z_end = min(z_start + batch_size, pims_images.expected_shape.z)
+                # return shapes and set to union when using --pad
+                args.append((z_start, z_end))
+            with warnings.catch_warnings():
+                # Block alignmnent within the dataset should not be a problem, since shard-wise chunking is enforced.
+                # However, dataset borders might change between different parallelized writes, when sizes differ.
+                # For differing sizes, a separate warning is thrown, so block alignment warnings can be ignored:
+                warnings.filterwarnings(
+                    "ignore",
+                    message=_BLOCK_ALIGNMENT_WARNING,
+                    category=RuntimeWarning,
+                    module="webknossos",
+                )
+                # There are race-conditions about setting the bbox of the layer.
+                # The bbox is set correctly afterwards, ignore errors here:
+                warnings.filterwarnings(
+                    "ignore",
+                    message=".*properties were found on disk which are newer than the ones that were seen last time.*",
+                    category=UserWarning,
+                    module="webknossos",
+                )
+                with get_executor_for_args(None, executor) as executor:
+                    shapes_and_max_ids = wait_and_ensure_success(
+                        executor.map_to_futures(func_per_chunk, args),
+                        progress_desc="Creating layer from images",
+                    )
+                shapes, max_ids = zip(*shapes_and_max_ids)
+                if category == "segmentation":
+                    max_id = max(max_ids)
+                    cast(SegmentationLayer, layer).largest_segment_id = max_id
+                actual_size = Vec3Int(
+                    dimwise_max(shapes) + (pims_images.expected_shape.z,)
+                )
+                layer.bounding_box = (
+                    BoundingBox((0, 0, 0), actual_size)
+                    .from_mag_to_mag1(mag)
+                    .offset(topleft)
+                )
+            if pims_images.expected_shape != actual_size:
+                warnings.warn(
+                    "Some images are larger than expected, smaller slices are padded with zeros now. "
+                    + f"New size is {actual_size}, expected {pims_images.expected_shape}.",
+                    RuntimeWarning,
+                )
+            if first_layer is None:
+                first_layer = layer
+        assert first_layer is not None
+        return first_layer
 
     def get_segmentation_layer(self) -> SegmentationLayer:
         """
@@ -1666,13 +1794,16 @@ class RemoteDataset(Dataset):
                 exist_ok=True,
                 read_only=True,
             )
-        except FileNotFoundError:
-            warnings.warn(
-                f"Cannot open remote webknossos dataset {dataset_path} as zarr. "
-                + "Returning a stub dataset instead, accessing metadata properties might still work.",
-                RuntimeWarning,
-            )
-            self.path = None  # type: ignore[assignment]
+        except FileNotFoundError as e:
+            if hasattr(self, "_properties"):
+                warnings.warn(
+                    f"Cannot open remote webknossos dataset {dataset_path} as zarr. "
+                    + "Returning a stub dataset instead, accessing metadata properties might still work.",
+                    RuntimeWarning,
+                )
+                self.path = None  # type: ignore[assignment]
+            else:
+                raise e from None
         self._dataset_name = dataset_name
         self._organization_id = organization_id
         self._sharing_token = sharing_token
@@ -1716,6 +1847,7 @@ class RemoteDataset(Dataset):
         display_name: Optional[str] = _UNSET,
         description: Optional[str] = _UNSET,
         is_public: bool = _UNSET,
+        folder_id: str = _UNSET,
         tags: List[str] = _UNSET,
     ) -> None:
         from webknossos.client._generated.api.default import dataset_update
@@ -1736,6 +1868,8 @@ class RemoteDataset(Dataset):
             info["tags"] = tags
         if is_public is not _UNSET:
             info["isPublic"] = is_public
+        if folder_id is not _UNSET:
+            info["folderId"] = folder_id
         if display_name is not _UNSET:
             info["displayName"] = display_name
 
@@ -1818,6 +1952,7 @@ class RemoteDataset(Dataset):
 
     @allowed_teams.setter
     def allowed_teams(self, allowed_teams: Sequence[Union[str, "Team"]]) -> None:
+        """Assign the teams that are allowed to access the dataset. Specify the teams like this `[Team.get_by_name("Lab_A"), ...]`."""
         from webknossos.administration.user import Team
         from webknossos.client._generated.api.default import dataset_update_teams
         from webknossos.client.context import _get_generated_client
@@ -1834,3 +1969,12 @@ class RemoteDataset(Dataset):
             assert (
                 dataset_update_teams_response.status_code == 200
             ), dataset_update_teams_response
+
+    @property
+    def folder(self) -> RemoteFolder:
+        return RemoteFolder.get_by_id(self._get_dataset_info().folder_id)
+
+    @folder.setter
+    def folder(self, folder: RemoteFolder) -> None:
+        """Move the dataset to a folder. Specify the folder like this `RemoteFolder.get_by_path("Datasets/Folder_A")`."""
+        self._update_dataset_info(folder_id=folder.id)
