@@ -1,6 +1,6 @@
 from webknossos.geometry import Vec3Int
 
 DEFAULT_WKW_FILE_LEN = 32
-DEFAULT_CHUNK_SIZE = Vec3Int.full(32)
+DEFAULT_CHUNK_SHAPE = Vec3Int.full(32)
 DEFAULT_CHUNKS_PER_SHARD = Vec3Int.full(32)
 DEFAULT_CHUNKS_PER_SHARD_ZARR = Vec3Int.full(1)
