@@ -10,6 +10,7 @@ from typing import TYPE_CHECKING, Dict, List, Optional, Tuple, Union
 
 import numpy as np
 from cluster_tools import Executor
+from numpy.typing import DTypeLike
 from upath import UPath
 
 from webknossos.dataset.sampling_modes import SamplingModes
@@ -54,11 +55,6 @@ from .defaults import (
 )
 from .mag_view import MagView, _find_mag_path_on_disk
 
-try:
-    from numpy.typing import DTypeLike
-except ImportError:
-    DTypeLike = Union[str, np.dtype, type]  # type: ignore[misc]
-
 
 def _is_int(s: str) -> bool:
     try:
@@ -390,7 +386,7 @@ class Layer:
         if chunk_shape not in (Vec3Int.full(32), Vec3Int.full(64)):
             warnings.warn(
                 "[INFO] `chunk_shape` of `32, 32, 32` or `64, 64, 64` is recommended for optimal "
-                + f"performance in webKnossos. Got {chunk_shape}."
+                + f"performance in WEBKNOSSOS. Got {chunk_shape}."
             )
 
         self._assert_mag_does_not_exist_yet(mag)
@@ -812,6 +808,7 @@ class Layer:
         `executor` can be passed to allow distrubuted computation, parallelizing
         across chunks. `args` is deprecated.
         """
+        self._dataset._ensure_writable()
 
         if args is not None:
             warn_deprecated(
@@ -980,6 +977,7 @@ class Layer:
 
         `min_mag` is deprecated, please use `finest_mag` instead.
         """
+        self._dataset._ensure_writable()
 
         if args is not None:
             warn_deprecated(
