@@ -2,22 +2,11 @@ import warnings
 from argparse import Namespace
 from pathlib import Path
 from types import TracebackType
-from typing import (
-    TYPE_CHECKING,
-    Any,
-    Callable,
-    Dict,
-    Iterable,
-    Optional,
-    Tuple,
-    Type,
-    Union,
-)
+from typing import TYPE_CHECKING, Any, Callable, Dict, Iterable, Optional, Tuple, Type
 
-import cluster_tools
 import numpy as np
 import wkw
-from cluster_tools.schedulers.cluster_executor import ClusterExecutor
+from cluster_tools import Executor
 
 from ..geometry import BoundingBox, Mag, Vec3Int, Vec3IntLike
 from ..utils import (
@@ -38,6 +27,12 @@ def _assert_check_equality(args: Tuple["View", "View", int]) -> None:
     assert np.all(view_a.read() == view_b.read())
 
 
+_BLOCK_ALIGNMENT_WARNING = (
+    "Warning: write() was called on a compressed mag without block alignment. "
+    + "Performance will be degraded as the data has to be padded first."
+)
+
+
 class View:
     """
     A `View` is essentially a bounding box to a region of a specific `StorageBackend` that also provides functionality.
@@ -257,7 +252,7 @@ class View:
     def _handle_compressed_write(
         self, current_mag_bbox: BoundingBox, data: np.ndarray
     ) -> Tuple[BoundingBox, np.ndarray]:
-        aligned_bbox = current_mag_bbox.align_with_mag(self.info.shard_size, ceil=True)
+        aligned_bbox = current_mag_bbox.align_with_mag(self.info.shard_shape, ceil=True)
 
         if current_mag_bbox != aligned_bbox:
 
@@ -265,8 +260,7 @@ class View:
             current_mag_view_bbox = self.bounding_box.in_mag(self._mag)
             if current_mag_bbox != current_mag_view_bbox.intersected_with(aligned_bbox):
                 warnings.warn(
-                    "Warning: write() was called on a compressed mag without block alignment. "
-                    + "Performance will be degraded as the data has to be padded first.",
+                    _BLOCK_ALIGNMENT_WARNING,
                     RuntimeWarning,
                 )
 
@@ -315,7 +309,7 @@ class View:
 
         # ...
         # let mag1 be a MagView
-        view = mag1.get_view(absolute_offset(10, 20, 30), size=(100, 200, 300))
+        view = mag1.get_view(absolute_offset=(10, 20, 30), size=(100, 200, 300))
 
         assert np.array_equal(
             view.read(absolute_offset=(0, 0, 0), size=(100, 200, 300)),
@@ -574,7 +568,7 @@ class View:
 
             current_mag_bbox = mag1_bbox.in_mag(self._mag)
             current_mag_aligned_bbox = current_mag_bbox.align_with_mag(
-                self.info.shard_size, ceil=True
+                self.info.shard_shape, ceil=True
             )
             # The data bbox should either be aligned or match the dataset's bounding box:
             current_mag_view_bbox = self.bounding_box.in_mag(self._mag)
@@ -603,6 +597,7 @@ class View:
         *,
         relative_offset: Optional[Vec3IntLike] = None,  # in mag1
         absolute_offset: Optional[Vec3IntLike] = None,  # in mag1
+        use_logging: bool = False,
     ) -> "BufferedSliceWriter":
         """
         The returned writer buffers multiple slices before they are written to disk.
@@ -644,6 +639,7 @@ class View:
             dimension=dimension,
             relative_offset=relative_offset,
             absolute_offset=absolute_offset,
+            use_logging=use_logging,
         )
 
     def get_buffered_slice_reader(
@@ -655,6 +651,7 @@ class View:
         *,
         relative_bounding_box: Optional[BoundingBox] = None,  # in mag1
         absolute_bounding_box: Optional[BoundingBox] = None,  # in mag1
+        use_logging: bool = False,
     ) -> "BufferedSliceReader":
         """
         The returned reader yields slices of data along a specified axis.
@@ -691,19 +688,20 @@ class View:
             dimension=dimension,
             relative_bounding_box=relative_bounding_box,
             absolute_bounding_box=absolute_bounding_box,
+            use_logging=use_logging,
         )
 
     def for_each_chunk(
         self,
         func_per_chunk: Callable[[Tuple["View", int]], None],
-        chunk_size: Optional[Vec3IntLike] = None,  # in Mag(1)
-        executor: Optional[
-            Union[ClusterExecutor, cluster_tools.WrappedProcessPoolExecutor]
-        ] = None,
+        chunk_shape: Optional[Vec3IntLike] = None,  # in Mag(1)
+        executor: Optional[Executor] = None,
         progress_desc: Optional[str] = None,
+        *,
+        chunk_size: Optional[Vec3IntLike] = None,  # deprecated
     ) -> None:
         """
-        The view is chunked into multiple sub-views of size `chunk_size` (in Mag(1)),
+        The view is chunked into multiple sub-views of size `chunk_shape` (in Mag(1)),
         by default one chunk per file.
         Then, `func_per_chunk` is performed on each sub-view.
         Besides the view, the counter `i` is passed to the `func_per_chunk`,
@@ -716,7 +714,7 @@ class View:
 
         Example:
         ```python
-        from webknossos.utils import get_executor_for_args, named_partial
+        from webknossos.utils import named_partial
 
         def some_work(args: Tuple[View, int], some_parameter: int) -> None:
             view_of_single_chunk, i = args
@@ -732,14 +730,19 @@ class View:
         ```
         """
 
-        if chunk_size is None:
-            chunk_size = self._get_file_dimensions_mag1()
+        if chunk_shape is None:
+            if chunk_size is not None:
+                warn_deprecated("chunk_size", "chunk_shape")
+                chunk_shape = Vec3Int(chunk_size)
+                self._check_chunk_shape(chunk_shape, read_only=self.read_only)
+            else:
+                chunk_shape = self._get_file_dimensions_mag1()
         else:
-            chunk_size = Vec3Int(chunk_size)
-            self._check_chunk_size(chunk_size, read_only=self.read_only)
+            chunk_shape = Vec3Int(chunk_shape)
+            self._check_chunk_shape(chunk_shape, read_only=self.read_only)
 
         job_args = []
-        for i, chunk in enumerate(self.bounding_box.chunk(chunk_size, chunk_size)):
+        for i, chunk in enumerate(self.bounding_box.chunk(chunk_shape, chunk_shape)):
             chunk_view = self.get_view(
                 absolute_offset=chunk.topleft,
                 size=chunk.size,
@@ -771,16 +774,17 @@ class View:
         self,
         func_per_chunk: Callable[[Tuple["View", "View", int]], None],
         target_view: "View",
-        source_chunk_size: Optional[Vec3IntLike] = None,  # in Mag(1)
-        target_chunk_size: Optional[Vec3IntLike] = None,  # in Mag(1)
-        executor: Optional[
-            Union[ClusterExecutor, cluster_tools.WrappedProcessPoolExecutor]
-        ] = None,
+        source_chunk_shape: Optional[Vec3IntLike] = None,  # in Mag(1)
+        target_chunk_shape: Optional[Vec3IntLike] = None,  # in Mag(1)
+        executor: Optional[Executor] = None,
         progress_desc: Optional[str] = None,
+        *,
+        source_chunk_size: Optional[Vec3IntLike] = None,  # deprecated
+        target_chunk_size: Optional[Vec3IntLike] = None,  # deprecated
     ) -> None:
         """
         This method is similar to `for_each_chunk` in the sense that it delegates work to smaller chunks,
-        given by `source_chunk_size` and `target_chunk_size` (both in Mag(1),
+        given by `source_chunk_shape` and `target_chunk_shape` (both in Mag(1),
         by default using the larger of the source_views and the target_views file-sizes).
         However, this method also takes another view as a parameter. Both views are chunked simultaneously
         and a matching pair of chunks is then passed to the function that shall be executed.
@@ -789,10 +793,10 @@ class View:
         Additionally to the two views, the counter `i` is passed to the `func_per_chunk`, which can be used for logging.
 
         The mapping of chunks from the source view to the target is bijective.
-        The ratio between the size of the `source_view` (`self`) and the `source_chunk_size` must be equal to
-        the ratio between the `target_view` and the `target_chunk_size`. This guarantees that the number of chunks
+        The ratio between the size of the `source_view` (`self`) and the `source_chunk_shape` must be equal to
+        the ratio between the `target_view` and the `target_chunk_shape`. This guarantees that the number of chunks
         in the `source_view` is equal to the number of chunks in the `target_view`.
-        The `target_chunk_size` must be a multiple of the file size on disk to avoid concurrent writes.
+        The `target_chunk_shape` must be a multiple of the file size on disk to avoid concurrent writes.
 
         Example use case: *downsampling from Mag(1) to Mag(2)*
         - size of the views: `16384³` (`8192³` in Mag(2) for `target_view`)
@@ -800,42 +804,47 @@ class View:
           (`1024³` in Mag(2), which fits the default file-length of 32*32)
         """
 
-        if source_chunk_size is None or target_chunk_size is None:
+        if source_chunk_shape is None and source_chunk_size is not None:
+            warn_deprecated("source_chunk_size", "source_chunk_shape")
+            source_chunk_shape = source_chunk_size
+
+        if target_chunk_shape is None and target_chunk_size is not None:
+            warn_deprecated("target_chunk_size", "target_chunk_shape")
+            target_chunk_shape = target_chunk_size
+
+        if source_chunk_shape is None or target_chunk_shape is None:
             assert (
-                source_chunk_size is None and target_chunk_size is None
-            ), "Either both source_chunk_size and target_chunk_size must be given or none."
-            source_chunk_size = self._get_file_dimensions_mag1().pairmax(
+                source_chunk_shape is None and target_chunk_shape is None
+            ), "Either both source_chunk_shape and target_chunk_shape must be given or none."
+            source_chunk_shape = self._get_file_dimensions_mag1().pairmax(
                 target_view._get_file_dimensions_mag1()
             )
-            target_chunk_size = source_chunk_size
+            target_chunk_shape = source_chunk_shape
         else:
-            source_chunk_size = Vec3Int(source_chunk_size)
-            target_chunk_size = Vec3Int(target_chunk_size)
-            self._check_chunk_size(source_chunk_size, read_only=True)
-            target_view._check_chunk_size(
-                target_chunk_size, read_only=target_view.read_only
+            source_chunk_shape = Vec3Int(source_chunk_shape)
+            target_chunk_shape = Vec3Int(target_chunk_shape)
+            self._check_chunk_shape(source_chunk_shape, read_only=True)
+            target_view._check_chunk_shape(
+                target_chunk_shape, read_only=target_view.read_only
             )
 
-        assert (
-            not self.bounding_box.is_empty()
-        ), "Calling 'for_zipped_chunks' failed because the size of the source view contains a 0."
-        assert (
-            not target_view.bounding_box.is_empty()
-        ), "Calling 'for_zipped_chunks' failed because the size of the target view contains a 0."
+        if self.bounding_box.is_empty() or target_view.bounding_box.is_empty():
+            return
+
         assert np.array_equal(
             self.bounding_box.size.to_np() / target_view.bounding_box.size.to_np(),
-            source_chunk_size.to_np() / target_chunk_size.to_np(),
+            source_chunk_shape.to_np() / target_chunk_shape.to_np(),
         ), (
             "Calling 'for_zipped_chunks' failed because the ratio of the view sizes "
             + f"(source size = {self.bounding_box.size}, target size = {target_view.bounding_box.size}) "
             + "must be equal to the ratio of the chunk sizes "
-            + f"(source_chunk_size in Mag(1) = {source_chunk_size}, target_chunk_size in Mag(1) = {target_chunk_size})"
+            + f"(source_chunk_shape in Mag(1) = {source_chunk_shape}, target_chunk_shape in Mag(1) = {target_chunk_shape})"
         )
 
         job_args = []
-        source_chunks = self.bounding_box.chunk(source_chunk_size, source_chunk_size)
+        source_chunks = self.bounding_box.chunk(source_chunk_shape, source_chunk_shape)
         target_chunks = target_view.bounding_box.chunk(
-            target_chunk_size, target_chunk_size
+            target_chunk_shape, target_chunk_shape
         )
 
         for i, (source_chunk, target_chunk) in enumerate(
@@ -874,11 +883,18 @@ class View:
     def content_is_equal(
         self,
         other: "View",
-        args: Optional[Namespace] = None,
+        args: Optional[Namespace] = None,  # deprecated
+        executor: Optional[Executor] = None,
     ) -> bool:
+        if args is not None:
+            warn_deprecated(
+                "args argument",
+                "executor (e.g. via webknossos.utils.get_executor_for_args(args))",
+            )
+
         if self.bounding_box.size != other.bounding_box.size:
             return False
-        with get_executor_for_args(args) as executor:
+        with get_executor_for_args(args, executor) as executor:
             try:
                 self.for_zipped_chunks(
                     _assert_check_equality,
@@ -915,24 +931,24 @@ class View:
         pass
 
     def __repr__(self) -> str:
-        return repr(f"View({self._path}, bounding_box={self.bounding_box})")
+        return f"View({repr(str(self._path))}, bounding_box={self.bounding_box})"
 
-    def _check_chunk_size(self, chunk_size: Vec3Int, read_only: bool) -> None:
-        assert chunk_size.is_positive(
+    def _check_chunk_shape(self, chunk_shape: Vec3Int, read_only: bool) -> None:
+        assert chunk_shape.is_positive(
             strictly_positive=True
-        ), f"The passed parameter 'chunk_size' {chunk_size} contains at least one 0. This is not allowed."
+        ), f"The passed parameter 'chunk_shape' {chunk_shape} contains at least one 0. This is not allowed."
 
-        divisor = self.mag.to_vec3_int() * self.info.chunk_size
+        divisor = self.mag.to_vec3_int() * self.info.chunk_shape
         if not read_only:
             divisor *= self.info.chunks_per_shard
-        assert chunk_size % divisor == Vec3Int.zeros(), (
-            f"The chunk_size {chunk_size} must be a multiple of "
-            + f"mag*chunk_size{'*chunks_per_shard' if not read_only else ''} of the view, "
+        assert chunk_shape % divisor == Vec3Int.zeros(), (
+            f"The chunk_shape {chunk_shape} must be a multiple of "
+            + f"mag*chunk_shape{'*chunks_per_shard' if not read_only else ''} of the view, "
             + f"which is {divisor})."
         )
 
     def _get_file_dimensions(self) -> Vec3Int:
-        return self.info.shard_size
+        return self.info.shard_shape
 
     def _get_file_dimensions_mag1(self) -> Vec3Int:
         return self._get_file_dimensions() * self.mag.to_vec3_int()
@@ -951,7 +967,8 @@ class View:
             self._cached_array = None
 
     def __del__(self) -> None:
-        del self._cached_array
+        if hasattr(self, "_cached_array"):
+            del self._cached_array
 
     def __getstate__(self) -> Dict[str, Any]:
         d = dict(self.__dict__)
@@ -965,3 +982,9 @@ class View:
 
 def _count_defined_values(values: Iterable[Optional[Any]]) -> int:
     return sum(i is not None for i in values)
+
+
+def _copy_job(args: Tuple[View, View, int]) -> None:
+    (source_view, target_view, _) = args
+    # Copy the data form one view to the other in a buffered fashion
+    target_view.write(source_view.read())
